********************************************************************************
*
*Construct network measures based on previous 12 months
*
********************************************************************************

	
********************************************************************************
*Load monthly network panel
********************************************************************************

	frame create network_rolling
	frame change network_rolling
	
	use "$data/Network_panel_monthly_filtered.dta", clear
	
	sum date
			*Start date for analysis is 687 - April 2017
			*So need network between May 2015 and April 2016 for first month (May 2015 is 664, April 2016 is 675)
			*Last month is March 2021 - 734
			*So relevant network is from April 2019 to March 2020 (711 to 722)
		
********************************************************************************
*Split data set
********************************************************************************

	foreach date of numlist 660/722{
	preserve
		local date12 = `date'-12
		
		keep if date>`date12' & date<=`date'
		

		collapse (sum) transaction_volume buyer_sales supplier_sales buyer_purchases supplier_purchases buyer_imports supplier_imports buyer_exports supplier_exports supplier_sales_network_monthly buyer_purch_network_monthly (max) ln_time buyer_isic supplier_isic buyer_sector supplier_sector , by(supplier_id buyer_id)
			rename supplier_sales_network_monthly supplier_sales_network
			rename buyer_purch_network_monthly buyer_purch_network
			
	*********************
	*Buyer's share of firm's overall sales
	gen buyer_share=(transaction_volume/(supplier_sales_network))
	egen total_buyer_shares=total(buyer_share), by(supplier_id )	
		replace total_buyer_shares=1 if total_buyer_shares>1 & total_buyer_shares<1.01


	*********************
	*Supplier's share of firm's overall purchases
	gen supplier_share=(transaction_volume/(buyer_purch_network))
	egen total_supplier_shares=total(supplier_share), by(buyer_id )	
		replace total_supplier_shares=1 if total_supplier_shares>1 & total_supplier_shares<1.01

	********************
	*Create diversification and complexity measures
	
		cap rename buyer_purchases buyer_purch
		**************
		*Market share of buyer 
		gen market_share_sales=transaction_volume/(buyer_purch+buyer_imports )*100
				replace market_share_sales=100 if market_share_sales>100 & market_share_sales<=110
				replace market_share_sales=. if market_share_sales>110
				replace market_share_sales=. if market_share_sales<0
					label variable market_share_sales "Market share among buyer's purchases"

		
		**************
		*HHI sales
				replace supplier_exports=0 if supplier_exports==.
				replace buyer_imports=0 if buyer_imports==.
		gen market_shares_supplier=transaction_volume/(supplier_exports+supplier_sales)*100
		replace market_shares_supplier=100 if market_shares_supplier>100 & market_shares_supplier<=110
		replace market_shares_supplier=. if market_shares_supplier>110 | market_shares_supplier<0
		
		egen hhi_sales=total((market_shares_supplier/100)^2), by(supplier_id )
			replace hhi_sales=1 if hhi_sales>1 & hhi_sales!=. //50 obs

		*By industry (Isic class code)
				egen supplier_industry_volume=total(transaction_volume), by(supplier_id buyer_isic )
			gen supplier_industry_share=(transaction_volume/supplier_industry_volume)*100
			replace supplier_industry_share=. if supplier_industry_share>110 | supplier_industry_share<0
			replace supplier_industry_share=100 if supplier_industry_share>100 & supplier_industry_share<=110
		egen hhi_wi_industry_sales=total((supplier_industry_share/100)^2), by(supplier_id buyer_isic )
					egen byte tag=tag(supplier_id buyer_isic  )

		egen hhi_industry_sales=mean(hhi_wi_industry_sales) if tag==1, by(supplier_id )
			replace hhi_industry_sales=1 if hhi_industry_sales>1 & hhi_industry_sales!=.
		
		
		egen industry_count_sales=total(tag), by(supplier_id )
		egen buyer_count_industry=count(transaction_volume), by(supplier_id buyer_isic )
		
			label variable hhi_industry_sales "Avg concentration of sales by industry"
			label variable industry_count_sales "# of industries firm's buyers operate in"
			label variable buyer_count_industry "# of buyers per industry"

			cap drop tag hhi_wi_industry_sales
			
		
		**************
		*HHI purchases
		gen market_shares_buyer=transaction_volume/(buyer_purch+buyer_imports )*100
		replace market_shares_buyer=. if market_shares_buyer>110 | market_shares_buyer<0
		replace market_shares_buyer=100 if market_shares_buyer>100 & market_shares_buyer<=110

		egen hhi_purch=total((market_shares_buyer/100)^2), by(buyer_id )
			replace hhi_purch=1 if hhi_purch>1 & hhi_purch!=. //615

		*By industry (Isic class code)
				egen buyer_industry_volume=total(transaction_volume), by(buyer_id supplier_isic  )
			gen buyer_industry_share=(transaction_volume/buyer_industry_volume)*100
			replace buyer_industry_share=. if buyer_industry_share>110 | buyer_industry_share<0
			replace buyer_industry_share=100 if buyer_industry_share>100 & buyer_industry_share<=110
		egen hhi_wi_industry_purch=total((buyer_industry_share/100)^2), by(buyer_id supplier_isic )
					egen byte tag=tag(buyer_id supplier_isic  )

		egen hhi_industry_purch=mean(hhi_wi_industry_purch) if tag==1, by(buyer_id  )
			replace hhi_industry_purch=1 if hhi_industry_purch>1 & hhi_industry_purch!=.
		egen industry_count_purch=total(tag), by(buyer_id  )
		egen supplier_count_industry=count(transaction_volume), by(buyer_id supplier_isic  )
		
			label variable hhi_industry_purch "Avg concentration of purchases by industry"
			label variable industry_count_purch "# of industries firm's suppliers operate in"
			label variable supplier_count_industry "# of suppliers per industry"
			cap drop tag hhi_wi_industry_purch

		**********************
		*Prepare for saving
		gen networkdate=`date'
			format networkdate %tm
			
		keep supplier_id buyer_id networkdate hhi_sales hhi_industry_sales industry_count_sales buyer_count_industry hhi_purch hhi_industry_purch industry_count_purch supplier_count_industry buyer_share supplier_share ln_time transaction_volume
			compress

	tempfile network`date'
	save `network`date'', replace
	
	restore
	}

********************************************************************************
*Append monthly network data sets
********************************************************************************

		frame create Rnetwork
		frame change Rnetwork
	foreach date of numlist 660/722{
		append using `network`date''
	}
	compress
		
	save "$data/Rolling_network_panel_monthly.dta", replace
