*******************************************************************************
*
*Master file for generating import and export shock measures linking transaction-level customs records with monthly UNComtrade data
*
*******************************************************************************

	
********************************************************************************
*Create data frames and load required data sets
********************************************************************************

	do "01_load_data.do"

********************************************************************************
*HS4 harmonisation & merging of customs data to VAT data 
********************************************************************************

	*****************
	*Customs harmonisation at the 4 digits level & computing rolling total exports and imports outside EAC
		
		do "02_imports_HS4_harmonisation.do"
		
		do "03_exports_HS4_harmonisation.do"

	*****************
	*Merging X & M, and reducing datasets to relevant firms & adding vars using balanced monthly firm level data set
	
		do "04_map2_firm_level_data.do"
	
********************************************************************************
*Compute direct exposure shares
********************************************************************************

		do "10_compute_import_shares.do"
		
		do "11_compute_export_shares.do"

		
********************************************************************************
*Compute shock measures
********************************************************************************

		do "12_merge_with_UNComtrade_shocks.do"
	
		do "13_test_shift_share_validity.do"
		
		do "14_aggregate2_firm_level.do"

********************************************************************************
*Save data set
********************************************************************************

		frame change final_IV_monthly
			gen year = year(dofm(date))
			
			compress
		save "$data/IV_trade_shock_monthly_Rnetwork.dta", replace 
		

