*******************************************************************************
*
*Generate exposure shares for imports
*
*******************************************************************************

*******************************************************************************
*Create shares using country-product-level import data set
*******************************************************************************

			frame change customs_imports 
			
		*******************************
		*Compute total inputs
		
		*total inputs using VAT data 
		cap drop total_inputs
		gen total_inputs = total_salary + total_imports + total_purchases
			label variable total_inputs "Inputs (labour cost + domestic purchases + imports (from VAT))"
		
		*Total imports using Customs data 	
		cap drop TotM_customs
			bysort tax_payer_id date:  egen TotM_customs = total(import_tradevalue) if import_tradevalue !=.
				label var TotM_customs "Total imports from customs data"
				

		*total inputs using Customs data 
		cap drop total_inputs_customs
		gen total_inputs_customs = total_salary + TotM_customs + total_purchases
			label variable total_inputs_customs "Inputs (labour cost + domestic purchases + imports (from customs))"	
			
	
		*******************************
		*Compute shares
		
		cap drop share_*
		
		*Using total_inputs from VAT  as denominator
			gen share_M_totInp = (import_tradevalue/total_inputs)
				replace share_M_totInp = 0 if total_inputs == 0 |  total_inputs == .
				replace share_M_totInp = 0 if import_tradevalue == 0 |  import_tradevalue == .
				
				
		*Using total_inputs from Customs as denominator
			gen share_M_totInp_customs = (import_tradevalue/total_inputs_customs) 
				replace share_M_totInp_customs = 0 if total_inputs_customs == 0 |  total_inputs_customs == .
				replace share_M_totInp_customs = 0 if import_tradevalue == 0 |  import_tradevalue == .
				

	******************************
	*Data checks
		
		summ share_*, de 			

		cap drop sum_*
		ds share_*
		foreach var of varlist `r(varlist)' {
			
			egen sum_`var' = total(`var'), by(tax_payer_id date) missing
			
		}	
			summ sum_share_*, de 
			
	
	**************************
	*Exploring outliers
		
		sum sum_share_M_totInp, detail 
		local p90 = `r(p90)'
		count if sum_share_M_totInp>`p90' 
			
		
		forvalues x = 2015(1)2021 {
			display `x'
			count if sum_share_M_totInp>`p90' & year==`x'
		}
		

	**************************
	*Re-weighting the shares to account for cases with customs and VAT discrepancies
		
	
		local var share_M_totInp
		
			sum sum_`var', detail
			replace `var' = . if sum_`var' > `r(p90)'
			replace `var' = `var' / sum_`var' if sum_`var'>1 & sum_`var'<=`r(p90)'
		
		
		*check again whether they sum to one 
		
				local var share_M_totInp
		cap drop sum_`var'
	
			egen sum_`var' = total(`var'), by(tax_payer_id date) missing

		
			summ sum_share_M_totInp , de 
			
			tab year if sum_share_M_totInp==.
			tab year

			label variable sum_share_M_totInp_customs "Sum of shares product imports without EAC (using customs in denominator)"
			label variable sum_share_M_totInp "Sum of shares product imports without EAC (using VAT in denominator)"
