*******************************************************************************
*
*Generate exposure shares for exports
*
*******************************************************************************

*******************************************************************************
*Create shares using country-product-level export data set
*******************************************************************************

			frame change customs_exports 
			
		
		cap drop share_*
		
		*******************************
		*Compute shares
		
		*Using sales as denominator
			gen share_X_Sales = (export_tradevalue/sales)
				replace share_X_Sales = 0 if sales == 0 |  sales == .
				replace share_X_Sales = 0 if export_tradevalue == 0 |  export_tradevalue == .
				
		*Using sum of exports from Customs as denominator 
			cap drop TotX_customs
			bysort tax_payer_id date:  egen TotX_customs = total(export_tradevalue) if export_tradevalue !=.
			
			gen share_X_totX_customs = (export_tradevalue/(total_sales+TotX_customs))
				replace share_X_totX_customs = 0 if total_sales+TotX_customs == 0 | total_sales+TotX_customs==.
			
		
	******************************
	*Data checks
		summ share_*, de 
			
		cap drop sum_*
		ds share_*
		foreach var of varlist `r(varlist)' {
			
			bysort tax_payer_id date : egen sum_`var' = total(`var')
			
		}
		
		*checking the vars that should approx one 
			summ sum_share_*, de 
			
	**************************
	*Exploring outliers
		
		sum sum_share_X_Sales, detail
		local p90 = `r(p90)'
		
		count if sum_share_X_Sales>`p90'  
			
		forvalues x = 2015(1)2021 {
			display `x'
			count if sum_share_X_Sales>`p90'  & year==`x'
		}
		
	**************************
	*Re-weighting the shares to account for cases with customs and VAT discrepancies
	
		local var share_X_Sales
		sum sum_`var', detail
		local p90 = `r(p90)'
		
		
			replace `var' = . if sum_`var' > `p90' 
			replace `var' = `var' / sum_`var' if sum_`var'>1 & sum_`var'<=`p90'
		
		
		*check again whether they sum to one 
		local var share_X_Sales
		cap drop sum_`var'
			
			egen sum_`var' = total(`var'), by(tax_payer_id date) missing

		
			summ sum_`var', de 
