********************************************************************************
*
*Test assumptions of shift-share 
*
********************************************************************************

********************************************************************************
*Variation
********************************************************************************

	frame copy UNComtrade_shock_monthly shockvariation

		 foreach trade in imports exports {
		 	
			*Data frame 
			frame change customs_`trade'

	tempfile tradefile
	save `tradefile', replace

	frame change shockvariation 
	
				*Merge 
				merge 1:m country_ISO2 hs_code date using `tradefile'
					rename _merge reverse_cov_`trade'
				duplicates drop country_ISO2 hs_code date, force

		 }
		 
********************************************************************************
*Number of countries, products and combinations
********************************************************************************

	****************
	*Product-country pairs
	
	foreach x in exports imports{
		egen tag_products_`x'=tag(hs_code) if reverse_cov_`x'==3
		egen tag_countries_`x'=tag(country_code) if reverse_cov_`x'==3
		egen tag_pc_`x'=tag(hs_code country_code) if reverse_cov_`x'==3 
			tab tag_products_`x' if reverse_cov_`x'==3
			tab tag_countries_`x' if reverse_cov_`x'==3
			tab tag_pc_`x' if reverse_cov_`x'==3
			
		gen unique_shocks_`x'=(reverse_cov_`x'==3)
	}
	
	
	rename delta12_log_wes_tv delta12_log_imports_tv
	rename delta12_log_wid_tv delta12_log_exports_tv
	
	************************
	*Mean, standard deviation and inter quartile range
	foreach x in exports imports{

	egen mean_`x'=mean(delta12_log_`x'_tv) if reverse_cov_`x'==3
	egen sd_`x'=sd(delta12_log_`x'_tv) if reverse_cov_`x'==3
	egen iqr_`x'=iqr(delta12_log_`x'_tv) if reverse_cov_`x'==3
	
	reghdfe delta12_log_`x'_tv if reverse_cov_`x'==3, absorb(hs_code) residuals(res_product_`x')
	egen mean_dp_`x'=mean(res_product_`x') if reverse_cov_`x'==3
	egen sd_dp_`x'=sd(res_product_`x') if reverse_cov_`x'==3
	egen iqr_dp_`x'=iqr(res_product_`x') if reverse_cov_`x'==3
	
	reghdfe delta12_log_`x'_tv if reverse_cov_`x'==3, absorb(country_code) residuals(res_country_`x')
	egen mean_dc_`x'=mean(res_country_`x') if reverse_cov_`x'==3
	egen sd_dc_`x'=sd(res_country_`x') if reverse_cov_`x'==3
	egen iqr_dc_`x'=iqr(res_country_`x') if reverse_cov_`x'==3
	
	}
		  
		 
		
	**************************
	*Correlation of shocks

		egen product_id=group(hs_code)
		egen t=group(date)
		
	***********
	*Within period shock variation
	foreach x in exports imports{

	*2020 test
	mixed delta12_log_`x'_tv t if reverse_cov_`x'==3 & year==2020  || country_code: t, nocons cov(exchangeable) || id_country_product: || , vce(robust)
local total = (exp(_b[lns1_1_1:_cons])^2+exp(_b[lns2_1_1:_cons])^2+exp(_b[lnsig_e:_cons])^2)

	}
	
	frame copy shockvariation shocktable
	frame change shocktable 
	
	collapse (max) mean_* sd_* iqr_* cp_var_* country_var_* (sum) tag_products_* tag_countries_* tag_pc_* unique_shocks_*
	
	foreach x in mean sd iqr cp_var country_var tag_products tag_countries tag_pc unique_shocks mean_dp sd_dp iqr_dp mean_dc sd_dc iqr_dc{
		preserve
		gen indicator="`x'"
		rename `x'_exports exports
		rename `x'_imports imports
		
		keep indicator exports imports
		tempfile ind`x'
		save `ind`x'', replace
		restore
	}
	
	frame create shshtable
	frame change shshtable
	
	use `indtag_countries', clear
	
	foreach x in tag_products tag_pc unique_shocks mean sd iqr  country_var cp_var mean_dp sd_dp iqr_dp mean_dc sd_dc iqr_dc {
		append using `ind`x''
	}
	
********************************************************************************
*Shares
********************************************************************************

		 	*****************
			*Imports
			
			frame copy customs_imports import_shares
			frame change import_shares
			
			collapse (mean) import_share=share_M_totInp   if share_M_totInp>0, by(country_code hs_code id_country_product date)
			
				egen sum_shares=total(import_share)
				gen norm_share=import_share/sum_shares
				
				gen import_share2=(norm_share)^2
				egen hhi=total(import_share2)
				gen inverse_hhi=1/hhi
				
				
			collapse (mean) mean_share=norm_share (p50) median_share=norm_share (max) max_share=norm_share hhi inverse_hhi
			
				foreach x in mean_share median_share max_share inverse_hhi{
					preserve
					gen indicator="`x'"
					rename `x' imports
					
					keep indicator imports
					tempfile ind`x'
					save `ind`x'', replace
					restore
				}
					frame change shshtable
				foreach x in mean_share median_share max_share inverse_hhi {
					append using `ind`x''
				}
		
				
			*****************
			*Exports
			
			frame copy customs_exports export_shares
			frame change export_shares
			
			collapse (mean) export_share=share_X_Sales   if share_X_Sales>0, by(country_code hs_code id_country_product date)
			
				egen sum_shares=total(export_share)
				gen norm_share=export_share/sum_shares
				
				gen export_share2=(norm_share)^2
				egen hhi=total(export_share2)
				gen inverse_hhi=1/hhi
				
				
			collapse (mean) mean_share=norm_share (p50) median_share=norm_share (max) max_share=norm_share hhi inverse_hhi

				foreach x in mean_share median_share max_share inverse_hhi{
					preserve
					gen indicator="`x'"
					rename `x' exports
					
					keep indicator exports
					tempfile ind`x'
					save `ind`x'', replace
					restore
				}
					frame change shshtable

				foreach x in mean_share median_share max_share inverse_hhi {

					merge 1:1 indicator using `ind`x'', update
						cap drop _merge
				}


********************************************************************************
*Output table
********************************************************************************

	order indicator exports imports
	
		format imports %12.3gc
		format exports %12.3gc
		
	gen order=.
	
	replace order=1 if indicator=="tag_countries"
	replace indicator="Countries" if indicator=="tag_countries"
	
	replace order=2 if indicator=="tag_products"
	replace indicator="Products" if indicator=="tag_products"
	
	replace order=3 if indicator=="tag_pc"
	replace indicator="Country x products" if indicator=="tag_pc"
		
	replace order=4 if indicator=="inverse_hhi"
	replace indicator="Effective sample size (1/HHI of $\omega_{cpt}$)" if indicator=="inverse_hhi"

	replace order=5 if indicator=="mean_share"
	replace indicator="Avg. $\omega_{cpt}$" if indicator=="mean_share"

	replace order=6 if indicator=="median_share"
	replace indicator="Median $\omega_{cpt}$" if indicator=="median_share"

	replace order=7 if indicator=="max_share"
	replace indicator="Max $\omega_{cpt}$" if indicator=="max_share"

	replace order=8 if indicator=="mean"
	replace indicator="Avg. $\Delta$ log world demand/supply" if indicator=="mean"

	replace order=9 if indicator=="sd"
	replace indicator="Standard deviation $\Delta$ log world demand/supply" if indicator=="sd"

	replace order=10 if indicator=="iqr"
	replace indicator="Interquartile range $\Delta$ log world demand/supply" if indicator=="iqr"

	replace order=11 if indicator=="country_var"
	replace indicator="Intra-country correlation" if indicator=="country_var"

	replace order=12 if indicator=="cp_var"
	replace indicator="Intra-country-product correlation" if indicator=="cp_var"

	sort order
	
		listtab indicator exports imports if order!=. ///
		using "$WDRnR/tables/GVC_descriptives/shift-share_validity_checks.tex", ///
		rstyle(tabular) replace ///
		head("\begin{tabular}{lrr}" "\hline\hline" " & Exports & Imports\\" "\hline" ) ///
		foot("\hline\hline""\end{tabular}")

		listtab indicator exports imports if order!=. ///
		using "$WD/tables/GVC_descriptives/shift-share_validity_checks.tex", ///
		rstyle(tabular) replace ///
		head("\begin{tabular}{lrr}" "\hline\hline" " & Exports & Imports\\" "\hline" ) ///
		foot("\hline\hline""\end{tabular}")
		
		listtab indicator exports imports if order!=. ///
		using "$tables/GVC_descriptives/shift-share_validity_checks.tex", ///
		rstyle(tabular) replace ///
		head("\begin{tabular}{lrr}" "\hline\hline" " & Exports & Imports\\" "\hline" ) ///
		foot("\hline\hline""\end{tabular}")
		