********************************************************************************
*
*Create list of nodes with relevant monthly characteristics for Python
*
********************************************************************************

********************************************************************************
*Load annual firm data with corrected shares
********************************************************************************

	frame change firms
	
		keep tax_payer_id networkdate isic_class_code sector_id isic_group_code r_iX* r_iH* r_iM* sales 
		
********************************************************************************
*Add shock measures
********************************************************************************

	*********************************
	*Shocks to exports and imports
		gen date = networkdate+12
			drop if date>734
		
	merge 1:1 tax_payer_id date using "$data/IV_trade_shock_monthly_Rnetwork.dta", keepusing(IV_imports_shcustoms_delta12 IV_exports_shcustoms_delta12  sum_share_M_totInp_customs sum_share_M_totInp IV_imports_shVAT_delta12 IV_exports_shVAT_delta12 sum_share_X_totX_customs sum_share_X_Sales)
		drop if _merge==2		

			****************************
			*UNcomtrade data (2018-2021)
			global Comtrade IV_imports_shcustoms_delta12 IV_exports_shcustoms_delta12   
			
			*Customs in denominator
			foreach var of varlist $Comtrade{
				replace `var'=0 if  `var'==.
			}
			
			rename IV_exports_shcustoms_delta12 exportUN_customs12
			rename IV_imports_shcustoms_delta12 importUN_customs12
			rename IV_exports_shVAT_delta12 exportUN_VAT12
			rename IV_imports_shVAT_delta12 importsUN_VAT12


		********************************
		*Sum of shares
		foreach var of varlist sum_share*{
			replace `var'=0 if `var'==.
		}

			cap drop _merge

********************************************************************************
*Rename sum of shares
********************************************************************************

	rename sum_share_M_totInp_customs sum_share_imports_customs
	rename sum_share_M_totInp sum_share_imports_VAT
	rename sum_share_X_totX_customs sum_share_exports_customs
	rename sum_share_X_Sales sum_share_exports_VAT

********************************************************************************
*Weighted shock measures
********************************************************************************
	xtset tax_payer_id date
	
	********************************
	*International shocks
	global exportshocks   exportUN_VAT12 exportUN_customs12
	global importshocks  importsUN_VAT12 importUN_customs12
	
		*Exports
		foreach x of varlist  $exportshocks{
		label variable `x' "Export shock"

		gen X`x' = `x'
			replace X`x' = 0 if X`x'==.
		label var X`x' "Export shock"
	}

		*Imports
		foreach x of varlist  $importshocks{
		label variable `x' "Import shock"

		gen M`x' = `x' 
			replace M`x' = 0 if M`x'==.
		label var M`x' "Import shock"
	}	

********************************************************************************
*Prepare node list and export 
********************************************************************************
	
	
	sum date if date>695
	
foreach date of numlist `r(min)'/`r(max)'{
	
	sum date  if date>695
	local start = `r(min)'
	
	frame copy firms firms_`date'
	frame change firms_`date'
	
	
	keep if date == `date'
	local dateL12 = `date'-12
	
	****************
	*Tag firms in network
	merge m:1 tax_payer_id networkdate using "$data/Working_files/full_shock_exposure/Input/firmlist_network_`dateL12'.dta", keepusing(tax_payer_id)
	
	
	xtset tax_payer_id date, monthly
	tsfill, full
	bysort tax_payer_id: carryforward date _merge , replace

	gen network=(_merge>1)
		label variable network "Firm participates in firm-to-firm trade"
	
	***************
	*Save complete firm list with weights and shocks (includes firms that do not feature in network)
	preserve
	cap drop _merge
	compress

	if `date' == `start' {
	save "$data/Working_files/full_shock_exposure/Output/direct_shocks_monthly.dta", replace
		
	}
	else{
	append using "$data/Working_files/full_shock_exposure/Output/direct_shocks_monthly.dta"
	sleep 50000
	save "$data/Working_files/full_shock_exposure/Output/direct_shocks_monthly.dta", replace

	}
	restore 
	
	****************
	*Restrict to firms in the network
	drop if _merge==1
	cap drop _merge
		*There should ne no _merge==2, i.e. firms that are only in the network

	***************
	*Prepare for python
	rename tax_payer_id id
	keep date id r_iX r_iXc r_iMc r_iM X*12 M*12  networkdate sum_share_imports_customs sum_share_imports_VAT sum_share_exports_customs sum_share_exports_VAT
	
	global variables r_iX r_iXc r_iM* X*12 M*12 sum_share_imports_customs sum_share_imports_VAT sum_share_exports_customs sum_share_exports_VAT
		foreach var of varlist $variables{
			replace `var' = 0 if `var'==.
		}
	
		****************
		*Save data set
		save "$data/Working_files/full_shock_exposure/Input/shocks_monthly_`date'.dta", replace

	
	frame change firms
	frame drop firms_`date'
}
