********************************************************************************
*
*Exposure to foreign and domestic demand (annual for descriptives)
*
*Output: r_iX_total
*
********************************************************************************


********************************************************************************
*Run python for inversion
********************************************************************************

cd "$data/Working_files/full_shock_exposure/"

python

import networkx as nx
import scipy.sparse.linalg as spsl
import numpy as np
import pandas as pd

tol = 1e-8
#maxiter = 5000

#need +1 for range
for date in range(2019, 2022):
   
		# import data
		# direct exposure
	share="Input\\shocks_%d.dta" %(date)

		# Adjacency matrix
	#Downstream
	r_txt="Input\\r_matrix_%d.txt" %(date - 1)   
	rc_txt="Input\\rc_matrix_%d.txt" %(date - 1)   
		

		# Direct exposure measure data set used to define nodes
	nodes=pd.read_stata(share)
		
		# Create directed graph using adjacency matrix
	G1=nx.read_weighted_edgelist(r_txt, create_using=nx.DiGraph())
	G2=nx.read_weighted_edgelist(rc_txt, create_using=nx.DiGraph())

	print(nx.info(G1))	
		
		# Create data frame with nodes from directed graph
	vat=pd.DataFrame(data=np.asarray(nx.nodes(G1), dtype=np.float64), columns=['id'])
	vatc=pd.DataFrame(data=np.asarray(nx.nodes(G2), dtype=np.float64), columns=['id'])
		
		#Create sparse matrix using directed graph, CSC format recommended for inversion: https://docs.scipy.org/doc/scipy/reference/sparse.html
	A1=nx.to_scipy_sparse_matrix(G1,weight='weight', format='csc')
	A2=nx.to_scipy_sparse_matrix(G2,weight='weight', format='csc')
		
		#Create vector of ones
	B=np.ones((nx.number_of_nodes(G1),1))
		
		# Merge node information and node list from directed graph
	nodes=pd.merge(vat, nodes, how='inner', on='id')
	nodesc=pd.merge(vatc, nodes, how='inner', on='id')
		
		# SpeciXy data frame as values from node list
	rX=nodes['r_iX'].values
	rH=nodes['r_iH'].values
	rXc=nodes['r_iXc'].values
	rHc=nodes['r_iHc'].values

	print(len(rX))
	print(len(rH))    
	print(len(rXc))
	print(len(rHc))    
		
		# compute inverse and do product
	influenceX, info = spsl.lgmres(A1, rX, x0=B, atol=tol)
	influenceH, info = spsl.lgmres(A1, rH, x0=B, atol=tol)  
		
		#Repeat using values based on customs data
	influenceXc, info = spsl.lgmres(A2, rXc, x0=B, atol=tol)
	influenceHc, info = spsl.lgmres(A2, rHc, x0=B, atol=tol)  

		# clean
	nodes['r_iX_total']=np.array(influenceX, dtype=np.float64)
	nodes['r_iH_total']=np.array(influenceH, dtype=np.float64)
	nodes['r_iXc_total']=np.array(influenceXc, dtype=np.float64)
	nodes['r_iHc_total']=np.array(influenceHc, dtype=np.float64)
    
	if date == 2019 :
		temp = nodes
	else:
		temp = temp.append(nodes)
        
temp.to_stata("Output\\total_XH_exposure.dta")

end

