********************************************************************************
*
*Exposure to imports (annual for descriptives)
*
*Output: r_iM_total
*
********************************************************************************


********************************************************************************
*Run python for inversion
********************************************************************************
cd "$data/Working_files/full_shock_exposure"

python

import networkx as nx
import scipy.sparse.linalg as spsl
import numpy as np
import pandas as pd

tol = 1e-8
maxiter = 10000

#need +1 for range
for date in range(2019, 2022):
   
		# import data
		# direct exposure
	share="Input\\shocks_%d.dta" %(date)

		# Adjacency matrix
	#Downstream
	s_txt="Input\\s_matrix_%d.txt" %(date - 1)   
	sc_txt="Input\\sc_matrix_%d.txt" %(date - 1)   
		

		# Direct exposure measure data set used to define nodes
	nodes=pd.read_stata(share)
		
		# Create directed graph using adjacency matrix
	G1=nx.read_weighted_edgelist(s_txt, create_using=nx.DiGraph())
	G2=nx.read_weighted_edgelist(sc_txt, create_using=nx.DiGraph())

	print(nx.info(G1))	
	print(nx.info(G2))	
		
		# Create data frame with nodes from directed graph
	vat=pd.DataFrame(data=np.asarray(nx.nodes(G1), dtype=np.float64), columns=['id'])
	vatc=pd.DataFrame(data=np.asarray(nx.nodes(G2), dtype=np.float64), columns=['id'])
		
		#Create sparse matrix using directed graph, CSC format recommended for inversion: https://docs.scipy.org/doc/scipy/reference/sparse.html
	A1=nx.to_scipy_sparse_matrix(G1,weight='weight', format='csc')
	A2=nx.to_scipy_sparse_matrix(G2,weight='weight', format='csc')
		
		#Create vector of ones
	B=np.ones((nx.number_of_nodes(G1),1))
		
		# Merge node information and node list from directed graph
	nodes=pd.merge(vat, nodes, how='inner', on='id')
	nodesc=pd.merge(vatc, nodes, how='inner', on='id')
		
		# SpeciXy data frame as values from node list
	rM=nodes['r_iM'].values
	rMc=nodesc['r_iMc'].values

	print(len(rM))
	print(len(rMc))
	
		# compute inverse and do product
	influenceM, info = spsl.lgmres(A1, rM, x0=B, atol=tol, maxiter=maxiter)
	influenceMc, info = spsl.lgmres(A2, rMc, x0=B, atol=tol, maxiter=maxiter)

		# clean
	nodes['r_iM_total']=np.array(influenceM, dtype=np.float64)
 	nodes['r_iMc_total']=np.array(influenceMc, dtype=np.float64)
   
	if date == 2019 :
		temp = nodes
	else:
		temp = temp.append(nodes)
        
temp.to_stata("Output\\total_M_exposure.dta")

end

