********************************************************************************
*
*Compute total shock exposure measure for exports
*
********************************************************************************


********************************************************************************
*Run python for inversion
********************************************************************************
cd "$data/Working_files/full_shock_exposure"

python

import networkx as nx
import scipy.sparse.linalg as spsl
import numpy as np
import pandas as pd

tol = 1e-8
maxiter = 5000

#need +1 for range
for date in range(696, 735):

		# import data
		
		# Adjacency matrix
	r_txt="Input\\r_matrix_%d.txt" %(date - 12)   
	#rc_txt="Input\\rc_matrix_%d.txt" %(date - 12)   

		# Create directed graph using adjacency matrix
	G1=nx.read_weighted_edgelist(r_txt, create_using=nx.DiGraph())
	print(nx.info(G1))	
	#G2=nx.read_weighted_edgelist(rc_txt, create_using=nx.DiGraph())
	#print(nx.info(G2))	
		
		# Create data frame with nodes from directed graph
	vat=pd.DataFrame(data=np.asarray(nx.nodes(G1), dtype=np.float64), columns=['id'])
	#vatc=pd.DataFrame(data=np.asarray(nx.nodes(G2), dtype=np.float64), columns=['id'])
		
		#Create sparse matrix using directed graph, CSC format recommended for inversion: https://docs.scipy.org/doc/scipy/reference/sparse.html
	A1=nx.to_scipy_sparse_matrix(G1,weight='weight', format='csc')
	#A2=nx.to_scipy_sparse_matrix(G2,weight='weight', format='csc')

		#Create vector of ones
	B=np.ones((nx.number_of_nodes(G1),1))

	# direct exposure monthly
	share="Input\\shocks_monthly_%d.dta" %(date) 

	# Direct exposure measure data set used to define nodes
	nodes=pd.read_stata(share)
	print(len(nodes))
	#nodesc=pd.read_stata(share)
	#print(len(nodesc))
		
	# Merge node information and node list from directed graph
	nodes=pd.merge(vat, nodes, how='inner', on='id')
	#nodesc=pd.merge(vatc, nodesc, how='inner', on='id')
		
	# SpeciXy data frame as values from node list
	#Hd12log=nodes['Hd12_log_salesH'].values
	Xcd12log=nodes['XexportUN_customs12'].values
	Xd12log=nodes['XexportUN_VAT12'].values
		
	#print(len(Hd12log))
	print(len(Xd12log))
		
	# compute inverse and do product
	#influenceH12log, info = spsl.lgmres(A1, Hd12log, x0=Hd12log, atol=tol, maxiter=maxiter)
	influenceX12log, info = spsl.lgmres(A1, Xd12log, x0=Xd12log, atol=tol, maxiter=maxiter)
	influenceXc12log, info = spsl.lgmres(A1, Xcd12log, x0=Xcd12log, atol=tol, maxiter=maxiter)
		
	# clean
	#nodes['Hd12log_total']=np.array(influenceH12log, dtype=np.float64) 
	nodes['Xd12log_total']=np.array(influenceX12log, dtype=np.float64) 
	nodes['Xcd12log_total']=np.array(influenceXc12log, dtype=np.float64) 

	# indirect shocks
	#nodes['Hd12log_indirect']= nodes['Hd12log_total'] - nodes['Hd12_log_salesH']
	nodes['Xcd12log_indirect']= nodes['Xcd12log_total'] - nodes['XexportUN_customs12']
	nodes['Xd12log_indirect']= nodes['Xd12log_total'] - nodes['XexportUN_VAT12']

	
		# SpeciXy data frame as values from node list
	rX=nodes['sum_share_exports_VAT'].values
	rXc=nodes['sum_share_exports_customs'].values

		# compute inverse and do product
	influenceX, info = spsl.lgmres(A1, rX, x0=B, atol=tol)
		
		#Repeat using values based on customs data
	influenceXc, info = spsl.lgmres(A1, rXc, x0=B, atol=tol)

		# clean
	nodes['r_iX_total']=np.array(influenceX, dtype=np.float64)
	nodes['r_iXc_total']=np.array(influenceXc, dtype=np.float64)
		
		#indirect exposure
	nodes['r_iXc_indirect']= nodes['r_iXc_total'] - nodes['sum_share_exports_customs']
	nodes['r_iX_indirect']= nodes['r_iX_total'] - nodes['sum_share_exports_VAT']
	

	if date == 696:
		temp = nodes
	else:
		temp = temp.append(nodes)
			
temp.to_stata("Output\\total_shocks_monthly_Rnetwork.dta")

end
		
		
	use "Output/total_shocks_monthly_Rnetwork.dta", clear

		gen day = dofc( date )
		gen month=month(day)
		gen year=year(day)
		gen ym=ym(year, month)
		format %tm ym
		sum ym
		sum networkdate
		gen networkday=dofc(networkdate)
		gen networkmonth=month( networkday )
		gen networkyear=year( networkday)
		gen networkym=ym( networkyear, networkmonth)
		format %tm networkym
		
		replace date=ym
		replace networkdate=networkym
		
		drop *day *month *year *ym
		rename id tax_payer_id
		compress 
	save "Output/total_shocks_monthly_Rnetwork.dta", replace