********************************************************************************
*
*Compute total shock exposure measure for imports
*
********************************************************************************


********************************************************************************
*Run python for inversion
********************************************************************************
cd "$data/Working_files/full_shock_exposure"

python

import networkx as nx
import scipy.sparse.linalg as spsl
import numpy as np
import pandas as pd

tol = 1e-8
maxiter = 5000

#need +1 for range
for date in range(696, 735):

		# import data
		
		# Adjacency matrix
	r_txt="Input\\s_matrix_%d.txt" %(date - 12)   
	#rc_txt="Input\\sc_matrix_%d.txt" %(date - 12)   

		# Create directed graph using adjacency matrix
	G1=nx.read_weighted_edgelist(r_txt, create_using=nx.DiGraph())
	print(nx.info(G1))	
	#G2=nx.read_weighted_edgelist(rc_txt, create_using=nx.DiGraph())
	#print(nx.info(G2))	
		
		# Create data frame with nodes from directed graph
	vat=pd.DataFrame(data=np.asarray(nx.nodes(G1), dtype=np.float64), columns=['id'])
	#vatc=pd.DataFrame(data=np.asarray(nx.nodes(G2), dtype=np.float64), columns=['id'])
		
		#Create sparse matrix using directed graph, CSC format recommended for inversion: https://docs.scipy.org/doc/scipy/reference/sparse.html
	A1=nx.to_scipy_sparse_matrix(G1,weight='weight', format='csc')
	#A2=nx.to_scipy_sparse_matrix(G2,weight='weight', format='csc')

		#Create vector of ones
	B=np.ones((nx.number_of_nodes(G1),1))


	# direct exposure monthly
	share="Input\\shocks_monthly_%d.dta" %(date) 

	# Direct exposure measure data set used to define nodes
	nodes=pd.read_stata(share)
	print(len(nodes))
	#nodesc=pd.read_stata(share)
	#print(len(nodesc))
		
	# Merge node information and node list from directed graph
	nodes=pd.merge(vat, nodes, how='inner', on='id')
	#nodesc=pd.merge(vatc, nodesc, how='inner', on='id')
		
	# SpeciXy data frame as values from node list
	Mcd12log=nodes['MimportUN_customs12'].values
	Md12log=nodes['MimportsUN_VAT12'].values
	
	print(len(Md12log))
		
	# compute inverse and do product
	influenceM12log, info = spsl.lgmres(A1, Md12log, x0=Md12log, atol=tol, maxiter=maxiter)
	influenceMc12log, info = spsl.lgmres(A1, Mcd12log, x0=Mcd12log, atol=tol, maxiter=maxiter)
		
	# clean
	nodes['Md12log_total']=np.array(influenceM12log, dtype=np.float64) 
	nodes['Mcd12log_total']=np.array(influenceMc12log, dtype=np.float64) 

	# indirect shocks
	#nodes['Md12log_indirect']= nodes['Md12log_total'] - nodes['MimportUN_customs12']
	nodes['Md12log_indirect']= nodes['Md12log_total'] - nodes['MimportsUN_VAT12']
	nodes['Mcd12log_indirect']= nodes['Mcd12log_total'] - nodes['MimportUN_customs12']

		# SpeciXy data frame as values from node list
	rM=nodes['sum_share_imports_VAT'].values
	rMc=nodes['sum_share_imports_customs'].values

		# compute inverse and do product
	influenceM, info = spsl.lgmres(A1, rM, x0=B, atol=tol)
		
		#Repeat using values based on customs data
	influenceMc, info = spsl.lgmres(A1, rMc, x0=B, atol=tol)

		# clean
	nodes['r_iM_total']=np.array(influenceM, dtype=np.float64)
	nodes['r_iMc_total']=np.array(influenceMc, dtype=np.float64)
		
		#indirect exposure
	nodes['r_iMc_indirect']= nodes['r_iMc_total'] - nodes['sum_share_imports_customs']
	nodes['r_iM_indirect']= nodes['r_iM_total'] - nodes['sum_share_imports_VAT']
	

	if date == 696:
		temp = nodes
	else:
		temp = temp.append(nodes)
			
temp.to_stata("Output\\total_shocks_imports_monthly_Rnetwork.dta")

end
		
	use "Output/total_shocks_imports_monthly_Rnetwork.dta", clear

		gen day = dofc( date )
		gen month=month(day)
		gen year=year(day)
		gen ym=ym(year, month)
		format %tm ym
		sum ym
		sum networkdate
		gen networkday=dofc(networkdate)
		gen networkmonth=month( networkday )
		gen networkyear=year( networkday)
		gen networkym=ym( networkyear, networkmonth)
		format %tm networkym
		
		replace date=ym
		replace networkdate=networkym
		
		drop *day *month *year 
		rename id tax_payer_id
		compress 
	save "Output/total_shocks_imports_monthly_Rnetwork.dta", replace