********************************************************************************
*
*Compile comprehensive firm panel with shock exposure measures
*
*Output: Firm level panel with python output
*
********************************************************************************

foreach x in "monthly"{
	
	if "`x'" == "monthly" {
		local time `"date"'
		local time2 `"year month"'
		local match `"m"'
	}
	
********************************************************************************
*Load firm list (includig all firms outside network)
********************************************************************************

use "$data/Working_files/full_shock_exposure/Output/direct_shocks_`x'.dta", clear

keep tax_payer_id `time' year* sector_id isic_group_code isic_class_code r_iX* r_iH* r_iM* sector_sales_H ln_sales_H d*log_salesH dhs*_salesH Hd*log_salesH Hd*log_salesH network X* M*
order tax_payer_id `time' year* sector_id isic_group_code isic_class_code r_iX* r_iH* r_iM* sector_sales_H ln_sales_H d*log_salesH dhs*_salesH Hd*log_salesH Hd*log_salesH network X* M*

rename tax_payer_id id

********************************************************************************
*Merge with total export and domestic household demand shares
********************************************************************************

	merge `match':1 id year using "$data/Working_files/full_shock_exposure/Output/total_XH_exposure"
	
	cap drop _merge
	
	**********************
	*Replace shares with direct shares if firms do not participate in network
	foreach var of varlist r_iX r_iXc r_iH r_iHc{
		replace `var'_total= `var' if `var'_total ==.
		replace `var'_total=0 if `var'_total<0
		replace `var'_total=1 if `var'_total>1

	}

		label variable r_iX_total "Total export share"
		label variable r_iH_total "Total domestic household demand share"

		label variable r_iXc_total "Total export share (customs)"
		label variable r_iHc_total "Total domestic household demand share (customs)"

********************************************************************************
*Merge with total import shares
********************************************************************************

	merge `match':1 id year using "$finaldata/Working_files/full_shock_exposure/Output/total_M_exposure"
	
	cap drop _merge
	
	**********************
	*Replace shares with direct shares if firms do not participate in network and put min to zero
	foreach var of varlist r_iM r_iMc{
		replace `var'_total= `var' if `var'_total ==.
		replace `var'_total=0 if `var'_total<0
		gen above1_`var'=(`var'_total>1.05 & `var'_total!=.)
		replace `var'_total=1 if `var'_total>1
		
	}

		label variable r_iM_total "Total import share"
		label variable r_iM_total "Total import share (customs)"

********************************************************************************
*Add full exposure to demand and supply shocks
********************************************************************************

	if "`x'" == "monthly" {
		gen month=month(dofm(date))
		
	*Demand side shocks
	merge 1:1 id `time2' using "$data/Working_files/full_shock_exposure/Output/total_shocks_`x'_2021", keepusing(Hd*log_total Hd*log_indirect X*total X*indirect)
	cap drop _merge
	foreach num of numlist 1 12{
		cap label variable Hd`num'log_total "Total exposure to domestic demand shocks"
		cap label variable Hd`num'log_indirect "Indirect exposure to domestic demand shocks"
		cap label variable Xdlog_total "Total exposure to export shocks"
		cap label variable Xdlog_indirect "Indirect exposure to export shocks"

}
	
	*Supply side shocks
	merge 1:1 id `time2' using "$data/Working_files/full_shock_exposure/Output/total_shocks_imports_`x'_2021", keepusing(X*)
	cap drop _merge
	foreach num of numlist 1 12{
		cap label variable Md`num'log_total "Total exposure to import shocks"
		cap label variable Md`num'log_indirect "Indirect exposure to import shocks"
}

	}

	*Demand side shock
	merge 1:1 id `time2' using "$data/Working_files/full_shock_exposure/Output/total_shocks_`x'", keepusing(Hd*log_total Hd*log_indirect X*) update replace
	
	cap drop _merge
	
	if "`x'" == "annual"{
		label variable Hdlog_total "Total exposure to domestic demand shocks"
		label variable Hdlog_indirect "Indirect exposure to domestic demand shocks"
		label variable Xdlog_total "Total exposure to export shocks"
		label variable Xdlog_indirect "Indirect exposure to export shocks"
		
	}

	*Supply side shocks
	merge 1:1 id `time2' using "$data/Working_files/full_shock_exposure/Output/total_shocks_imports_`x'", keepusing(M*) update replace
	if "`x'" == "annual"{
		label variable Xdlog_total "Total exposure to import shocks"
		label variable Xdlog_indirect "Indirect exposure to import shocks"
		
	}
	
	cap drop _merge
	
rename id tax_payer_id
order tax_payer_id year year_original isic_group_code isic_class_code r_iX* r_iM*  r_iH* sector_sales_H ln_sales_H d*log_salesH dhs*_salesH Hd*log_salesH Hd*log_salesH Hd*log_total Hd*log_indirect X* network
compress
save "$data/Working_files/full_shock_exposure/Output/full_network_exposure_panel_`x'", replace
}