*******************************************************************************
*
*Prepare and load firm-level data
*
********************************************************************************


*******************************************************************************
*Load monthly shock exposure measure
*******************************************************************************

	frame create annualgvc
	frame change annualgvc
	
	use "$data/Working_files/full_shock_exposure/Output/full_network_exposure_panel_annual.dta", clear
		
	keep tax_payer_id year r_iX* r_iX*_total r_iM* r_iM*_total 
	rename r_* Ar_*
	tempfile gvc
	save `gvc', replace


*******************************************************************************
*Load balanced monthly firm panel
*******************************************************************************

	frame create firms_monthly
	frame change firms_monthly
			
	use "$data/Comprehensive_firm_panel_monthly.dta", clear

	cap drop _merge
	*Add annual exposure to global value chains
	merge m:1 tax_payer_id year using `gvc'
	drop if year<2016
	drop if _merge==2
	*Not merged firms are those that were not part of the network in prevous year or any point in time prior to 2018

	xtset tax_payer_id date


	
	gen start_month=month(start_date)
	gen start_my=ym(start_year, start_month)

		cap drop active2019
		cap drop activemax
		egen activemax=max(active) if year==2019, by(tax_payer_id)
		egen active2019=max(activemax), by(tax_payer_id)
		cap drop activemax

	*********************
	*Buyer and supplier count
	
	foreach var of varlist supplier_count_monthly buyer_count_monthly{
		gen ln_`var'=ln(`var')
	}
		rename ln_*_count_monthly ln_*
		
	******************
	*Domestic sales and purchases
	foreach var of varlist total_sales total_purchases{
		gen ln_`var'=ln(`var'+1)
	}
	rename ln_total_sales ln_domestic_sales
	rename ln_total_purchases ln_domestic_purchases
	
	label variable ln_sales "Sales"
	label variable ln_purch "Purchases"
	label variable ln_buyer "No. of buyers"
	label variable ln_supplier "No. of suppliers"
	label variable ln_domestic_purchases "Domestic purch."
	label variable ln_domestic_sales "Domestic sales"
	
	*****************
	*Z-scores
		cap drop z_*
		
		*Based on outcomes before November 2019
		foreach var of varlist ln_domestic_sales ln_exports ln_imports ln_domestic_purchases ln_employ ln_buyer ln_supplier{
		sum `var' if start_my<=date & date<718 & date>686
		gen z_score_`var' =(`var' -`r(mean)')/`r(sd)'  if start_my<=date 
		
}
	rename z_score_ln_* z_*
		

********************************************************************************
*Aggregate sectors
********************************************************************************
			gen sector_agg=.

			replace sector_agg=1 if sector_id==1 //Agriculture
			replace sector_agg=2 if sector_id==3 // Manufacturing
			replace sector_agg=3 if inlist(sector_id, 4, 5) //Utilities
			replace sector_agg=4 if sector_id==7 // Construction
			replace sector_agg=5 if sector_id==8 // Trade
			replace sector_agg=6 if sector_id==9 //Transport
			replace sector_agg=7 if sector_id==10 //Hospitality
			replace sector_agg=8 if inlist(sector_id, 11, 14, 15, 16, 18, 19, 20, 21, 22)
			replace sector_agg=9 if sector_id==2 // Mining
			replace sector_agg=10 if sector_agg==. & sector_id!=. & sector_id!=6 & sector_id!=17

			label define sector_agg 1 "Agriculture" 2 "Manufacturing" 3 "Utilities" 4 "Construction" 5 "Wholesale & Retail" 6 "Transport & Storage" 7 "Hospitality" 8 "Services" 9 "Mining" 10 "Others" , replace
			label values sector_agg sector_agg

	
********************************************************************************
*Event dummies
********************************************************************************	
	cap drop octob* novem* decem* jan* feb* march* april* may* june* 
	cap drop july* august* septem*
	cap drop m20_*
	cap drop m21_*

*2019 and 2020
foreach num of numlist 0/2{
    local year = 2018+`num'

	gen byte jan_`year'=(date==720-(12*(2-`num')))
	gen byte feb_`year'=(date==721-(12*(2-`num')))
	gen byte march_`year'=(date==722-(12*(2-`num')))
	gen byte april_`year'=(date==723-(12*(2-`num')))
	gen byte may_`year'=(date==724-(12*(2-`num')))
	gen byte june_`year'=(date==725-(12*(2-`num')))
	gen byte july_`year'=(date==726-(12*(2-`num')))
	gen byte august_`year'=(date==727-(12*(2-`num')))
	gen byte septem_`year'=(date==728-(12*(2-`num')))
	gen byte octob_`year'=(date==729-(12*(2-`num')))
	gen byte novem_`year'=(date==730-(12*(2-`num')))
	gen byte decem_`year'=(date==731-(12*(2-`num')))
	
			label variable jan_`year' "Jan"
			label variable feb_`year' "Feb"
			label variable march_`year' "Mar"
			label variable april_`year' "Apr"
			label variable may_`year' "May"
			label variable june_`year' "Jun"
			label variable july_`year' "Jul"
			label variable august_`year' "Aug"
			label variable septem_`year' "Sep"
			label variable octob_`year' "Oct"
			label variable novem_`year' "Nov"	
			label variable decem_`year' "Dec" 
			
		*Leave out January
			local minus = `year'-1
		global eventstudy`year'  novem_`minus' decem_`minus'   feb_`year' march_`year' april_`year' may_`year' june_`year' july_`year' august_`year' septem_`year' octob_`year' 
		global eventstudyorder`year'  novem_`minus' decem_`minus' jan_`year'  feb_`year' march_`year' april_`year' may_`year' june_`year' july_`year' august_`year' septem_`year' octob_`year' 
	
}

*2021
foreach num of numlist 1{
    local year = 2020+`num'

	gen byte jan_`year'=(date==720+(12*(`num')))
	gen byte feb_`year'=(date==721+(12*(`num')))
	gen byte march_`year'=(date==722+(12*(`num')))
	
			label variable jan_`year' "Jan"
			label variable feb_`year' "Feb"
			label variable march_`year' "Mar"
			
						local minus = `year'-1

		global eventstudy`year' novem_`minus' decem_`minus'  jan_`year'  feb_`year' march_`year' 
	
}

	*******************
	*Pre Covid months
		cap drop pre2020
		cap drop pre2019
		
	gen pre2020=(date<718)
	gen pre2019=(date<706)

			
