*******************************************************************************
*
*Add network measures from 12 months rolling network
* 
*******************************************************************************

		frame create Rnetwork
		frame change Rnetwork
		use "$data/Rolling_network_panel_monthly.dta", clear

********************************************************************************
*Collapse to firm level
********************************************************************************

	foreach firm in "buyer" "supplier"{
	
	if "`firm'" == "buyer" {
		local partner `"supplier"'
		local flow `"purch"'
	}
	
	else {
		local partner `"buyer"'
		local flow `"sales"'
	}
	
	************************************
	*Characteristics - weighted
	
	preserve
	
		********
		*Mean
			*Relationship and firm level measures
			global `firm'_weighted_mean  `partner'_weigh_time=ln_time 

			collapse  (mean) ${`firm'_weighted_mean}  [iw=`partner'_share], by(`firm'_id networkdate)
			

						rename `firm'_id tax_payer_id
						rename `partner'_weigh_time R`partner'_wtime
						compress
						
			tempfile `firm'_weighted
			save ``firm'_weighted', replace
			
	restore
	
	************************************
	*Characteristics - unweighted

	preserve
		**********
		*Max
			global `firm'_max hhi_`flow'  hhi_industry_`flow' industry_count_`flow' `partner'_count_industry

		collapse (count) `partner'_count=`partner'_id (max) ${`firm'_max} , by(`firm'_id networkdate)
					rename `firm'_id tax_payer_id
					rename hhi_`flow' Rhhi_`flow'
					rename hhi_industry_`flow' Rhhi_indu_`flow'
					rename industry_count_`flow' Rindu_count_`flow'
					rename `partner'_count_industry R`partner'_count_indu
					rename `partner'_count R`partner'_count
					compress
					
		tempfile `firm'_unweighted
		save ``firm'_unweighted', replace
	restore
	
		

	}
	


*******************************************************************************
*Add rolling network information to monthly firm panel
*******************************************************************************
	
	frame change firms_monthly

			cap drop _merge
			gen networkdate=date-12
				format networkdate %tm
				
	foreach firm in "buyer" "supplier"{

	
		merge 1:1 tax_payer_id networkdate using ``firm'_weighted'
			drop if _merge==2
			cap drop _merge
			
		merge 1:1 tax_payer_id networkdate using ``firm'_unweighted'
			drop if _merge==2
			cap drop _merge
		
			
		
	}				

********************************************************************************
*Sales and purchases of the past 12 months
********************************************************************************
	xtset tax_payer_id date
	
	tsegen Rsales_network=rowtotal(L(1/12).sales_network_monthly)
	tsegen Rpurch_network=rowtotal(L(1/12).purchases_network_monthly)
	
	tsegen Rsales_H=rowtotal(L(1/12).sales_H)
	
	gen Rfd_share=Rsales_H/(Rsales_network+Rsales_H)
		replace Rfd_share=1 if Rsales_network==. & Rsales_H!=.
		sum Rfd_share
	
compress

	frame drop Rnetwork
	
	