*******************************************************************************
*
*Split sample into firm heterogeneity groups (diversification, complexity, inventory)
* 
*******************************************************************************


********************************************************************************
*Pre and post Covid
********************************************************************************

	gen preC19=(date<=722)
	gen C19=(date>722 & date<726)
	gen postC19=(date>=726)
	
	xtset tax_payer_id date
	gen Lsales_decile=L12.sales_decile
		
		
	sum Rsupplier_wtime Rsupplier_count Rhhi_purch Rhhi_indu_purch Rindu_count_purch Rsupplier_count_indu Rbuyer_wtime Rbuyer_count Rhhi_sales Rhhi_indu_sales Rindu_count_sales Rbuyer_count_indu
	
	*************************************
	*Extensive margin diversification
	
		
		cap drop sales_ter* purch_ter*
		gen sales_ter=.
		gen purch_ter=.
		
		foreach sector of numlist 1/5 7/11 13/23{
	foreach age of numlist 1/4 {
	fastxtile sales_ter`sector' = Rsales_network if Rbuyer_count!=. & sector_id==`sector' & cohort==`age', nquantiles(4)	
	
		replace sales_ter=sales_ter`sector' if Rbuyer_count!=. & sector_id==`sector' & cohort==`age'
		
		cap drop sales_ter`sector'
	}
	}

	foreach x in "supplier" "buyer"{
		if "`x'"=="buyer"{
			local flow = "sales"
		}
		else{
			local flow = "purch"
		}
		
		cap drop div_ex_`flow'
		cap drop median_div*
		
		*Above median in own broad sector (2 digit)
		egen median_div_`x'=median(R`x'_count_indu), by(sector_id cohort sales_ter networkdate)
		
		gen div_ex_`flow'=(R`x'_count_indu>median_div_`x' & R`x'_count_indu!=.)
			replace div_ex_`flow'=. if R`x'_count_indu==.
	}
		
	*************************************
	*Intensive margin diversification
	
		*HHI industry
	sum Rhhi_indu_purch
	sum Rhhi_indu_sales
	
	**************************************
	*Complexity - number of sectors
		
	foreach x in "purch" "sales"{
		cap drop *_complex_`x'
		if "`x'"=="buyer"{
			local flow = "sales"
		}
		else{
			local flow = "purch"
		}
		
		*Above median in own broad sector
		egen median_complex_`x'=median(Rindu_count_`x'), by(isic_class_code networkdate)
		
		gen high_complex_`x'=(Rindu_count_`x'>median_complex_`x' & Rindu_count_`x'!=.)
			replace high_complex_`x'=. if Rindu_count_`x'==.
	}
	*We don't condition on sales quartile with complexity, but on smaller sector
		
	****************************************
	*Inventory based on CIT data
	gen cit=((gross_profit!=0 | total_assets!=0 | total_liabilities!=0 | fixed_assets!=0 | inventory!=0 ) & gross_profit!=.)
	gen Lcit=L12.cit
		replace Lcit=1 if year==2021 & L24.cit==1
	gen Linventory=L12.inventory
	gen inventory_ratio=(Linventory/L12.sales_annual)*365 if Lcit==1 // daily value of production held in inventory
		sum inventory_ratio, detail
		replace inventory_ratio=. if inventory_ratio>365*20

		
		*Above median in own broad sector
			egen tag_annual=tag(tax_payer_id year)
		egen p75_inventory=pctile(inventory_ratio) if tag_annual==1 & Lcit==1, by(isic_class_code year) p(75)
		egen max_p75_inventory=max(p75_inventory), by(tax_payer_id year)
			replace p75_inventory=max_p75_inventory
			drop max_p75_inventory
			
		gen high_inventory=(inventory_ratio>p75_inventory ) if p75_inventory>1 & Lcit==1
			replace high_inventory=L12.high_inventory if year==2021

		gen high_inventory60=(inventory_ratio>60 ) if p75_inventory>1 & Lcit==1
			replace high_inventory60=L12.high_inventory60 if year==2021

	**********************************************
	*Sector means of network position measures
	
	global network high_inventory60 high_inventory  div_ex_*  high_complex_* Rhhi_indu_* 
	
		foreach var of varlist $network{
				cap drop avg_`var'
			egen avg_`var'=mean(`var'), by(isic_class_code networkdate)
				label variable avg_`var' "4-digit sector avg of N"
		}
	
		*For regressions with hhi control for extensive margin equivalent as well
		
*********************************************************************************	
*Label variables
*********************************************************************************

		label variable div_ex_sales "diversification"
		label variable div_ex_purch "diversification"
		label variable Rhhi_indu_sales "sales HHI"
		label variable Rhhi_indu_purch "purchases HHI"
		label variable high_complex_sales "high # of sectors"
		label variable high_complex_purch "high # of sectors"
		label variable high_inventory "high inventory"

