*******************************************************************************
*
*Event study graphs with basic firm level outcomes
* 
*******************************************************************************


********************************************************************************
*Change the linewidth for coefplots
********************************************************************************

foreach num of numlist 1/10{
	grstyle linewidth p`num' thin
}

		
********************************************************************************
*Major firm outcomes
********************************************************************************

	**********************
	*Log 
	
	grstyle set color  #C6D4E1*1.5 #f1a340 dknavy maroon 

	global outcomes ln_domestic_sales ln_exports ln_domestic_purchases ln_imports
	estimates clear 
	
	foreach var of varlist $outcomes{
	reghdfe `var' pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store events`var'

	}
	coefplot events*, drop(_cons pre*) vertical yline(0)  ///
	text(-0.9 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.9 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts(recast(rcap)) order(novem_2019 decem_2019 jan_2020) omitted ///
	legend(label(2 "Domestic sales") label(4 "Exports") label(6 "Domestic purchases") label(8 "Imports") row(1))  ///
	ytitle("Log")
	
	graph export "$graphs/Event_study/event_study_major_flows_log.png", replace

		
*********************************************************************************************
*Event study with trends in previous years
*********************************************************************************************
	grstyle set color dknavy  #C6D4E1*1.2 
	
*******************************
*Simple event study with 2019 trends 
global outcomes ln_sales  ln_purch ln_exports ln_imports ln_buyer ln_supplier ln_domestic_sales ln_domestic_purchases

foreach var of  varlist $outcomes{
	estimates clear
	
	*Start with November 2019 (stata date 718)
reghdfe `var' pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store events2020
	
	*Start with November 2018 (stata date 706)
reghdfe `var' pre2019 $eventstudy2019 novem_2019 decem_2019 jan_2019 if date>674 & date<720 , absorb(tax_payer_id month) vce(cluster tax_payer_id)
	estimates store events2019
	
		coefplot (events2020, drop(_cons pre* ) msymbol(O) lpattern(solid) ) (events2019, drop(_cons pre*) rename(*_2019 = _2020 *_2018 = _2019) msymbol(D) lpattern(longdash)) , vertical yline(0)  ///
	text(-0.8 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.8 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts(recast(rcap)) order(novem_2019 decem_2019 jan_2020) omitted ///
	legend(label(2 "November 2019 - March 2021") label(4 "November 2018 - October 2019")) ///
	ytitle("`:variable label `var'' (log)")
	
	graph export "$graphs/Event_study/previous_year_norm_`var'.png", replace
	
}



********************************************************************************
*Heterogeneity by exposure to GVCs
********************************************************************************


	*Graph where firm was direct importer or exporter or neither
	
	********************
	*Importers and exporters - only direct
	cap drop g2019_*
	cap drop g1* g2* g3* g4*
	
	*****
	*Import
	gen g2019_2_proxy=(Ar_iM>=0.1 & Ar_iM!=.) if year==2020 & active2019==1
	egen g2019_2=max(g2019_2_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_2 "Importer (only)"
	
	******
	*Export 
	gen g2019_3_proxy=(Ar_iX>=0.1 & Ar_iX!=.) if year==2020 & active2019==1
	egen g2019_3=max(g2019_3_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_3 "Exporter (only)"
	
		
	********
	*Other
	gen byte g2019_1=(g2019_2==0 & g2019_3==0) if active2019==1
		label variable g2019_1 "No exposure"
	
	cap drop g2019_*_proxy
	
	
	grstyle set color  #C6D4E1*1.5 dknavy maroon 

		**********
		*Levels
		foreach num of numlist 1/3{
		reghdfe ln_sales pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 & sector_id!=10 & g2019_`num'==1 & active2019==1 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
		estimates store g`num'
		}
		
		
		coefplot ///
		(g1, drop(_cons  pre* ) msymbol(D) )  ///
		(g2, drop(_cons pre*  ) msymbol(S) )  ///
		(g3, drop(_cons  pre* )   )  ///
		 , vertical yline(0) yscale(r(0)) ///
		text(-0.9 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.9 14.5 "2021", placem(r) size(small)) ///
		xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts() order(novem_2019 decem_2019 jan_2020) omitted ///
		legend(order(2 "No exposure" 4 "Importer" 6 "Exporter" ) rows(1) ) ///
		ytitle("Sales (log)")
		graph export "$graphs/Event_study/event_study_levels_importer_exporter.png", replace
		
		*Only 205 firms both import and export - therefore combine with imports and exports
		
	**********************
	*Primary outcomes for individual subgroups 
	
	grstyle set color  #C6D4E1*1.5 #f1a340 dknavy maroon 
	foreach num of numlist 1/3{

	global outcomes ln_domestic_sales ln_exports ln_domestic_purchases ln_imports
	estimates clear 
	
	foreach var of varlist $outcomes{
	reghdfe `var' pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 & sector_id!=10 & g2019_`num'==1 & active2019==1  , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store events`var'

	}
	coefplot events*, drop(_cons pre*) vertical yline(0)  ///
	text(-0.9 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.9 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts(recast(rcap)) order(novem_2019 decem_2019 jan_2020) omitted ///
	legend(label(2 "Domestic sales") label(4 "Exports") label(6 "Domestic purchases") label(8 "Imports") row(1))  ///
	ytitle("Log")
	
	graph export "$graphs/Event_study/event_study_major_flows_GVC_group`num'.png", replace
		}

********************************************************************************
*Indirect exposure to GVCs
********************************************************************************

	grstyle set color dknavy*0.4 dknavy*0.75 dknavy*1.2

	********************************************************************************
	*Imports
	********************************************************************************
	
	cap drop g2019_*
	cap drop g1* g2* g3* g4*
	
	
	*****
	*Total imports
	gen g2019_2_proxy=(Ar_iM_total>=0.25 & Ar_iM<0.25 & Ar_iM_total!=. ) if year==2019 & active2019==1
	egen g2019_2=max(g2019_2_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_2 "High total imports"
	
	******
	*Direct imports 
	gen g2019_3_proxy=(Ar_iM>=0.25 &  Ar_iM!=. ) if year==2019 & active2019==1
	egen g2019_3=max(g2019_3_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_3 "High direct imports"
	
		
	********
	*Other
	gen byte g2019_1=(g2019_2==0 & g2019_3==0) if active2019==1
		label variable g2019_1 "No or low total imports"
	
	cap drop g2019_*_proxy
			estimates clear
	
		**********
		*Levels
		foreach num of numlist 1/3{
		reghdfe ln_sales pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 & sector_id!=10 & g2019_`num'==1 & active2019==1 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
		estimates store g`num'
		gen group`num'=(e(sample)==1)
		}
		
		
		coefplot ///
		(g1, drop(_cons  pre* ) msymbol(D) lpattern(shortdash))  ///
		(g2, drop(_cons pre*  ) msymbol(S) lpattern(longdash))  ///
		(g3, drop(_cons pre*  )   )  ///
		 , vertical yline(0) yscale(r(0)) ///
		text(-1.4 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-1.4 14.5 "2021", placem(r) size(small)) ///
		xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts() order(novem_2019 decem_2019 jan_2020) omitted ///
		legend(order(2 "No or low total imports" 4 "25%+ total imports" 6 "25%+ direct imports" ) rows(1) ) ///
		ytitle("Sales (log)")
		graph export "$graphs/Event_study/event_study_importers_indirect.png", replace
	

		************
		*Rename group indicators
		
		foreach num of numlist 1/3{
			egen group_max=max(group`num'), by(tax_payer_id)
			cap drop group`num'
			rename group_max group`num'
		}
		
		rename group1 imports_low
		rename group2 imports_total_high
		rename group3 imports_direct_high
		
		label variable imports_low "No or low total imports"
		label variable imports_direct_high "25%+ direct imports"
		label variable imports_total_high "25%+ total imports"
	
		replace imports_low=. if imports_low!=1 & imports_direct_high!=1 & imports_total_high!=1
		replace imports_total_high=. if imports_low!=1 & imports_direct_high!=1 & imports_total_high!=1
		replace imports_total_high=. if imports_low!=1 & imports_direct_high!=1 & imports_total_high!=1
		
		
	********************************************************************************
	*Exports
	********************************************************************************
	grstyle set color maroon*0.4 maroon*0.75 maroon*1.2
	
	cap drop g2019_*
	cap drop g1* g2* g3* g4*
	
	
	*****
	*Total exports
	gen g2019_2_proxy=(Ar_iX_total>=0.25 & Ar_iX<0.25 & Ar_iX_total!=. ) if year==2019 & active2019==1
	egen g2019_2=max(g2019_2_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_2 "High total imports"
	
	******
	*Direct exports 
	gen g2019_3_proxy=(Ar_iX>=0.25 &  Ar_iX!=. ) if year==2019 & active2019==1
	egen g2019_3=max(g2019_3_proxy) if active2019==1, by(tax_payer_id)
		label variable g2019_3 "High direct imports"
	
		
	********
	*Other
	gen byte g2019_1=(g2019_2==0 & g2019_3==0) if active2019==1
		label variable g2019_1 "Low exposure"
	
	cap drop g2019_*_proxy
			estimates clear
	
		**********
		*Levels
		foreach num of numlist 1/3{
		reghdfe ln_sales pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 & sector_id!=10 & g2019_`num'==1 & active2019==1 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
		estimates store g`num'
		gen group`num'=(e(sample)==1)

		}
		
		
		coefplot ///
		(g1, drop(_cons pre*  ) msymbol(D) lpattern(shortdash))  ///
		(g2, drop(_cons pre*  ) msymbol(S) lpattern(longdash))  ///
		(g3, drop(_cons pre*  )   )  ///
		 , vertical yline(0) yscale(r(0)) ///
		text(-0.8 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.8 14.5 "2021", placem(r) size(small)) ///
		xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts() order(novem_2019 decem_2019 jan_2020) omitted ///
		legend(order(2 "No or low total exports" 4 "25%+ total exports" 6 "25%+ direct exports" ) rows(1) ) ///
		ytitle("Sales (log)")
		graph export "$graphs/Event_study/event_study_exporters_indirect.png", replace
	
	
		************
		*Rename group indicators
		
		foreach num of numlist 1/3{
			egen group_max=max(group`num'), by(tax_payer_id)
			cap drop group`num'
			rename group_max group`num'
		}
		
		rename group1 exports_low
		rename group2 exports_total_high
		rename group3 exports_direct_high
		
		label variable exports_low "No or low total exports"
		label variable exports_direct_high "25%+ direct exports"
		label variable exports_total_high "25%+ total exports"
	
		replace exports_low=. if exports_low!=1 & exports_direct_high!=1 & exports_total_high!=1
		replace exports_total_high=. if exports_low!=1 & exports_direct_high!=1 & exports_total_high!=1
		replace exports_total_high=. if exports_low!=1 & exports_direct_high!=1 & exports_total_high!=1
		
		cap drop gvc_direct_low
		gen gvc_direct_low=(exports_direct_high==0 & imports_direct_high==0)
		
	**********************
	*Primary outcomes for high level exporters and importers 
	
	grstyle set color  #C6D4E1*1.5 #f1a340 dknavy maroon 
	foreach var of varlist exports_direct_high imports_direct_high gvc_direct_low{

	global outcomes ln_domestic_sales ln_exports ln_domestic_purchases ln_imports
	estimates clear 
	
	foreach outcome of varlist $outcomes{
	reghdfe `outcome' pre2020 $eventstudy2020 $eventstudy2021 jan_2020 if date>674 & sector_id!=10 & `var'==1 & active2019==1  , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store events`outcome'

	}
	coefplot events*, drop(_cons pre*) vertical yline(0)  ///
	text(-1.45 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-1.45 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l) ciopts(recast(rcap)) order(novem_2019 decem_2019 jan_2020) omitted ///
	legend(label(2 "Domestic sales") label(4 "Exports") label(6 "Domestic purchases") label(8 "Imports") row(1))  ///
	ytitle("Log") yscale(range(-1.5(0.5)1)) yla(-1.5(0.5)1)
	
	graph export "$graphs/Event_study/event_study_major_flows_GVC_`var'.png", replace

		}
		
		
		
