*******************************************************************************
*
*Share of GVC groups by sector and descriptive table on basic firm characteristics, import and export trends
* 
*******************************************************************************


	frame change firms_monthly
		
********************************************************************************
*Direct and indirect exposure share by sector
********************************************************************************

***************************************
*Weighted by firm sales

	foreach x in "imports" "exports"{
		
		if "`x'"=="imports"{
	grstyle set color maroon*0.4 maroon*0.75 maroon*1.2
		local flow = "purchases"
		}

	else{
		grstyle set color dknavy*0.4 dknavy*0.75 dknavy*1.2
		local flow = "sales"
	}

	preserve
	
		keep if date==706 & `x'_low!=.
		
			drop if sector_agg==.
		
			gen firm_share=.
			
		foreach sector of numlist 1/8{
			sum `flow'_annual if sector_agg==`sector'
			replace firm_share=`flow'_annual/`r(sum)'
		}
		
		collapse (sum) `x'_low `x'_total_high `x'_direct_high [iw=firm_share], by(sector_agg)	
		
			generate frac = (`x'_total_high+`x'_direct_high) /(`x'_low + `x'_total_high + `x'_direct_high)

		graph bar (asis) `x'_low `x'_total_high `x'_direct_high , ///
		over(sector_agg, sort(frac) descending label(angle(50))) stack percent ///
		ytitle("Percent") ///
		legend(label(1 "Low `x'") label(2 "25%+ total `x'") label(3 "25%+ direct `x'") rows(1)) 
		//note("", span)
		
	graph export "$graphs/GVC_descriptives/Shares_GVC_group_`x'.png", replace
		
	restore
	}

***************************************
*Unweighted

	foreach x in "imports" "exports"{
		
		if "`x'"=="imports"{
	grstyle set color maroon*0.4 maroon*0.75 maroon*1.2
		}

	else{
		grstyle set color dknavy*0.4 dknavy*0.75 dknavy*1.2
		
	}

	preserve
	
		keep if date==706 & `x'_low!=.
		
			drop if sector_agg==.
		
			
		
		collapse (sum) `x'_low `x'_total_high `x'_direct_high , by(sector_agg)	
		
			generate frac = (`x'_total_high+`x'_direct_high) /(`x'_low + `x'_total_high + `x'_direct_high)

		graph bar (asis) `x'_low `x'_total_high `x'_direct_high , ///
		over(sector_agg, sort(frac) descending label(angle(50))) stack percent ///
		ytitle("Percent") ///
		legend(label(1 "Low `x'") label(2 "25%+ total `x'") label(3 "25%+ direct `x'") rows(1)) 
		
	graph export "$graphs/GVC_descriptives/Shares_GVC_group_`x'_unweighted.png", replace
		
	restore
	}

		
********************************************************************************
*Summary stats on GVC exposure groups
********************************************************************************
		
	foreach x in "import" "export"{
	preserve
	
		keep if date==706
		
		
		gen `x'_groups=.
			replace `x'_groups=1 if `x's_low==1
			replace `x'_groups=2 if `x's_total_high==1
			replace `x'_groups=3 if `x's_direct_high==1
			
			drop if `x'_groups==.
			
		****************
		*sales in million
		replace sales_annual=sales_annual/1000000
		
		
		collapse (count) firm_count=tax_payer_id (mean) avg_age=firm_age avg_sales=sales_annual avg_employ=tot_employees avg_buyers=buyer_count avg_suppliers=supplier_count Rfd_share (sd) sd_age=firm_age sd_sales=sales_annual sd_employ=tot_employees (sum) group_sales=sales_annual , by(`x'_groups)
		
		
		****************
		*Sales share of group
		gen sales_share=.
		sum group_sales
		replace sales_share = (group_sales/`r(sum)')*100
		
		replace Rfd_share=Rfd_share*100

		****************
		*Format of the variables
		format firm_count %20.0gc
		format sales_share %6.0f
		format avg_sales %20.0fc
		format sd_sales %20.1gc
		format avg_employ %20.0f
		format sd_employ %20.0f
		format avg_age %20.0f
		format sd_age %20.0f
		format avg_suppliers %9.0f
		format avg_buyers %9.0f
		format Rfd_share %9.0f
		
		***************
		*Group title
		gen group_title=""
			replace group_title="No/low `x's" if `x'_groups==1
			replace group_title="25\%+ total `x's" if `x'_groups==2
			replace group_title="25\%+ direct `x's" if `x'_groups==3
			
				
		*********** 
		*Exporting table to Latex
				  
		listtab group_title firm_count  sales_share avg_age avg_sales sd_sales avg_employ sd_employ avg_buyers avg_suppliers Rfd_share ///
		using "$tables/GVC_descriptives/`x'_groups_basics.tex", ///
		rstyle(tabular) replace ///
		head("\begin{tabular}{l*{11}{c}}" "\hline\hline" "`x' group & \# of firms & \% of sales & Age  & \multicolumn{2}{c}{Sales} & \multicolumn{2}{c}{Employment} & No. buyers & No. suppliers & \% sales to HH\\" "\hline" " &  &   & avg & avg & sd & avg  & sd & avg & avg & avg\\" "\hline") ///
		foot("\hline\hline""\end{tabular}")
		

		restore
		
		}
		
		
********************************************************************************
*Binary link definition and links to large firms
********************************************************************************
		
		frame create annualnetwork
		frame change annualnetwork
		
		use "$data/Comprehensive_network_panel_annual.dta", clear
		
			keep if year==2018
			egen tag_suppliers=tag(supplier_id)
			sum supplier_no_buyers if tag_suppliers==1, detail
			gen supplier_p90=(supplier_importer==1 & supplier_no_buyers>=`r(p90)')
		
		collapse (max) supplier_importer supplier_p90 (count) supplier_id (sum) supplier_importer_count=supplier_importer, by(buyer_id)
		
			tab supplier_importer
			tab supplier_p90
		
		
********************************************************************************
*Importing patterns during the recovery phase
********************************************************************************
	frame change firms_monthly
	
	gen import_now=(total_imports>0) 
		tab import_now if imports_low==1 & date==706
		tab import_now if imports_low==1 & date==730	
		tab import_now if imports_low==1 & date==725	

		tab import_now if imports_total_high==1 & date==706
		tab import_now if imports_total_high==1 & date==730	
		tab import_now if imports_total_high==1 & date==725	

		tab import_now if imports_direct_high==1 & date==706
		tab import_now if imports_direct_high==1 & date==730	
		tab import_now if imports_direct_high==1 & date==725	

foreach num of numlist 1/10{
	grstyle linewidth p`num' medthick
}


	********************************
	*Imports

	grstyle set color maroon*0.4 maroon*0.75 maroon*1.2

	preserve
	gen import_group=1 if imports_low==1
		replace import_group=2 if imports_total_high==1
		replace import_group=3 if imports_direct_high==1
		
	collapse (sum) imports=total_imports, by(import_group date)
	
	egen total_imports=total(imports), by(date)
	gen import_share=imports/total_imports


	twoway (line import_share date if import_group==1, lpattern(shortdash)) (line import_share date if import_group==2, lpattern(longdash)) (line import_share date if import_group==3), ///
			legend(order(1 "No or low total imports" 2 "25%+ total imports" 3 "25%+ direct imports" ) rows(1) ) ytitle("Share of total imports")
		graph export "$graphs/Event_study/trends_import_shares.png", replace
		
	twoway (line imports date if import_group==1, lpattern(shortdash)) (line imports date if import_group==2, lpattern(longdash)) (line imports date if import_group==3), legend(order(1 "No or low total imports" 2 "25%+ total imports" 3 "25%+ direct imports" ) rows(1) ) ytitle("Share of total imports")

	restore
		 
		 

	***********************************************
	*Exports
	
	grstyle set color dknavy*0.4 dknavy*0.75 dknavy*1.2
		
	preserve
	gen export_group=1 if exports_low==1
		replace export_group=2 if exports_total_high==1
		replace export_group=3 if exports_direct_high==1
		
	collapse (sum) exports=total_exports, by(export_group date)
	
	egen total_exports=total(exports), by(date)
	gen export_share=exports/total_exports
	
	twoway (line export_share date if export_group==1, lpattern(shortdash)) (line export_share date if export_group==2, lpattern(longdash)) (line export_share date if export_group==3), ///
			legend(order(1 "No or low total exports" 2 "25%+ total exports" 3 "25%+ direct exports" ) rows(1) ) ytitle("Share of total exports")
		graph export "$graphs/Event_study/trends_export_shares.png", replace

	restore
		 
		
	foreach num of numlist 1/10{
	grstyle linewidth p`num' thin
}
	
		
		
		
		
		
		
		
		
