*******************************************************************************
*
*Heterogeneity by domestic network position
* 
*******************************************************************************

	cap drop preC19
	gen preC19=(date>717 & date<=722)
	cap gen C19=(inlist(date, 723, 724, 725))
	cap gen postC19=(date>725)
	
		label variable C19 " "
		label variable postC19 " "
		label variable preC19 " "
		
		cap drop ln_age
	gen ln_age=ln(firm_age)
		
		estimates clear
		
********************************************************************************
*Extensive margin diversification
********************************************************************************

	grstyle set color default, order(1 2 1 2 1 2 1)
		
	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}
	

foreach x in  "purch" "sales"{
	foreach var of varlist div_ex_`x' {

		if "`x'"=="purch"{
			local flow = "up"
		}
		else{
			local flow = "down"
		}
		

		cap drop C19`var'
		cap drop postC19`var'
		
		
		foreach month of varlist preC19 {
			cap drop `month'_`var'
			gen `month'_`var'=`month'*`var'
		}
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' "inter"
			label variable postC19`var' "inter"
			label variable preC19_`var' "inter"
		label variable C19 "base"
		label variable postC19 "base"
		label variable preC19 "base"

		estimates clear


	*Testing for pre-trends	
	reghdfe ln_sales `var' preC19 preC19_`var' C19 C19`var' postC19 postC19`var'   avg_`var' Rfd_share ln_age importer exporter if date>674 & sector_id!=10  , absorb(tax_payer_id sector_id#month ) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(preC19) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(preC19_`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(C19) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(C19`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(postC19) msymbol(O)  ) ///
		(`var', keep(postC19`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("Sales (log)") legend(order( 4 "no/low `flow'stream diversification" 2 "high `flow'stream diversification")) nooffsets ///
		groups(preC19* = "{bf:Pre C-19 period}" C19* = "{bf:C-19 peak}" postC19* = "{bf:Recovery}", nogap ) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)

	
	*****************
	*Graphs
	graph export "$graphs/Network_heterogeneity/covid_dummies_`var'.png", replace

	
			*******************
			*Tables
			label variable C19 "C-19 peak"
			label variable postC19 "C-19 recovery"
			label variable C19`var' "`: variable label C19'*`:variable label `var''"
			label variable postC19`var' "`: variable label postC19'*`:variable label `var''"
			label variable preC19 "Pre C-19 period"
			label variable preC19_`var' "`: variable label preC19' * `:variable label `var''"

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N df_a_nested r2  firm_fe  decfe sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. firms" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/covid_dummies_`var'.tex", $formatting $regshort $statslabelslr  
	
	}
}

********************************************************************************
*Complexity
********************************************************************************
foreach x in "sales" "purch"{

	foreach var of varlist high_complex_`x'{

		if "`x'"=="purch"{
			local flow = "up"
		}
		else{
			local flow = "down"
		}

		cap drop C19`var'
		cap drop postC19`var'
		foreach month of varlist preC19 {
			cap drop `month'_`var'
			gen `month'_`var'=`month'*`var'
		}
		
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' "inter"
			label variable postC19`var' "inter"
			label variable preC19_`var' "inter"
		label variable C19 "base"
		label variable postC19 "base"
		label variable preC19 "base"

		estimates clear

	reghdfe ln_sales `var' preC19 preC19_`var' C19 C19`var' postC19 postC19`var'   avg_`var' Rfd_share  if date>674 & sector_id!=10 , absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(preC19) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(preC19_`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(C19) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(C19`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(postC19) msymbol(O)  ) ///
		(`var', keep(postC19`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("Sales (log)") legend(order( 4 "low # of `flow'stream sectors" 2 "high # of `flow'stream sectors")) nooffsets ///
		groups(preC19* = "{bf:Pre C-19 period}" C19* = "{bf:C-19 peak}" postC19* = "{bf:Recovery}", nogap ) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)
	
	graph export "$graphs/Network_heterogeneity/covid_dummies_`var'.png", replace

			*******************
			*Tables
			label variable C19 "C-19 peak"
			label variable postC19 "C-19 recovery"
			label variable C19`var' "`: variable label C19'*`:variable label `var''"
			label variable postC19`var' "`: variable label postC19'*`:variable label `var''"
			label variable preC19 "Pre C-19 period"
			label variable preC19_`var' "`: variable label preC19' * `:variable label `var''"

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N df_a_nested r2  firm_fe  decfe sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. firms" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/covid_dummies_`var'.tex", $formatting $regshort $statslabelslr  

	
	}
}
********************************************************************************
*Concentration
********************************************************************************

	
foreach x in "sales" "purch"{
	
	foreach var of varlist Rhhi_indu_`x'{
	
		if "`x'"=="purch"{
			local flow = "supplier"
		}
		else{
			local flow = "buyer"
		}
			cap drop ln_R`flow'_count_indu
		gen ln_R`flow'_count_indu=ln(R`flow'_count_indu)

		cap drop C19`var'
		cap drop postC19`var'
		foreach month of varlist preC19 {
			cap drop `month'_`var'
			gen `month'_`var'=`month'*`var'
		}
		
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'

			label variable C19`var' "inter"
			label variable postC19`var' "inter"
			label variable preC19_`var' "inter"
		label variable C19 "base"
		label variable postC19 "base"
		label variable preC19 "base"

		estimates clear

	reghdfe ln_sales `var' preC19 preC19_`var' C19 C19`var' postC19 postC19`var'  ln_R`flow'_count_indu avg_`var'   if date>674 & sector_id!=10 , absorb(tax_payer_id sector_id#month ) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(preC19) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(preC19_`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(C19) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(C19`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(postC19) msymbol(O)  ) ///
		(`var', keep(postC19`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("Sales (log)") legend(order( 4 "low concentration of `x'" 2 "high concentration of `x'")) nooffsets ///
		groups(preC19* = "{bf:Pre C-19 period}" C19* = "{bf:C-19 peak}" postC19* = "{bf:Recovery}", nogap ) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)
	
	graph export "$graphs/Network_heterogeneity/covid_dummies_`var'.png", replace

			*******************
			*Tables
			label variable C19 "C-19 peak"
			label variable postC19 "C-19 recovery"
			label variable C19`var' "`: variable label C19'*`:variable label `var''"
			label variable postC19`var' "`: variable label postC19'*`:variable label `var''"
			label variable preC19 "Pre C-19 period"
			label variable preC19_`var' "`: variable label preC19' * `:variable label `var''"

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N df_a_nested r2  firm_fe  decfe sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. firms" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/covid_dummies_`var'.tex", $formatting $regshort $statslabelslr  

	}
}

********************************************************************************
*Inventory
********************************************************************************

	foreach var of varlist high_inventory {


		cap drop C19`var'
		cap drop postC19`var'
		foreach month of varlist preC19 {
			cap drop `month'_`var'
			gen `month'_`var'=`month'*`var'
		}
		
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' "inter"
			label variable postC19`var' "inter"
			label variable preC19_`var' "inter"
		label variable C19 "base"
		label variable postC19 "base"
		label variable preC19 "base"

		estimates clear

	reghdfe ln_sales `var' preC19 preC19_`var' C19 C19`var' postC19 postC19`var'   avg_`var' Rfd_share  if date>674 & sector_id!=10 & Lcit==1, absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(preC19) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(preC19_`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(C19) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(C19`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(postC19) msymbol(O)  ) ///
		(`var', keep(postC19`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("Sales (log)") legend(order( 4 "low inventory" 2 "high inventory")) nooffsets ///
		groups(preC19* = "{bf:Pre C-19 period}" C19* = "{bf:C-19 peak}" postC19* = "{bf:Recovery}", nogap ) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)
	
	graph export "$graphs/Network_heterogeneity/covid_dummies_`var'.png", replace

			*******************
			*Tables
			label variable C19 "C-19 peak"
			label variable postC19 "C-19 recovery"
			label variable C19`var' "`: variable label C19'*`:variable label `var''"
			label variable postC19`var' "`: variable label postC19'*`:variable label `var''"
			label variable preC19 "Pre C-19 period"
			label variable preC19_`var' "`: variable label preC19' * `:variable label `var''"

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N df_a_nested r2  firm_fe  decfe sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. firms" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/covid_dummies_`var'.tex", $formatting $regshort $statslabelslr  

	
	}



********************************************************************************
*Inventory & High diversification
********************************************************************************

	grstyle set color default, order(1 3 7 2 1 3 7 2 1 3 7 2 1 3 7)
		
		cap drop high_div_invent
	gen high_div_invent=high_inventory*div_ex_purch
	label variable high_div_invent "both"
	
	foreach var of varlist high_inventory high_div_invent div_ex_purch{


		cap drop C19`var'
		cap drop postC19`var'
		foreach month of varlist preC19 {
			cap drop `month'_`var'
			gen `month'_`var'=`month'*`var'
		}
		
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' "inter"
			label variable postC19`var' "inter"
			label variable preC19_`var' "inter"
		label variable C19 "base"
		label variable postC19 "base"
		label variable preC19 "base"
	}
		estimates clear

	reghdfe ln_sales   div_ex_purch high_inventory high_div_invent preC19 preC19_div_ex_purch preC19_high_inventory preC19_high_div_invent C19 C19div_ex_purch C19high_inventory C19high_div_invent postC19 postC19div_ex_purch postC19high_inventory postC19high_div_invent  avg_high_inventory avg_div_ex_purch Rfd_share  if date>674 & sector_id!=10 & Lcit==1, absorb(tax_payer_id sector_id#month) vce(cluster tax_payer_id)
	estimates store both
	

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (both, keep(div_ex_purch  ) msymbol(S) mfcolor(*.5) ) ///
		(both, keep(high_inventory ) msymbol(T) mfcolor(*.5) ) ///
		(both, keep(high_div_invent ) msymbol(D) mfcolor(*.5) ) ///
		(both, keep(preC19 ) msymbol(O)  mfcolor(*.3)  ) ///
		(both, keep(preC19_div_ex_purch) msymbol(S) mfcolor(*.3)  ) ///
		(both, keep(preC19_high_inventory) msymbol(T) mfcolor(*.3)  ) ///
		(both, keep(preC19_high_div_invent) msymbol(D) mfcolor(*.3)  ) ///
		(both, keep(C19) msymbol(O)  mfcolor(*.7)  ) ///
		(both, keep(C19div_ex_purch  ) msymbol(S) mfcolor(*.7)  ) ///
		(both, keep( C19high_inventory ) msymbol(T) mfcolor(*.7)  ) ///
		(both, keep(  C19high_div_invent) msymbol(D) mfcolor(*.7)  ) ///
		(both, keep(postC19) msymbol(O)  ) ///
		(both, keep(postC19div_ex_purch   ) msymbol(S)  ) ///
		(both, keep( postC19high_inventory  ) msymbol(T)  ) ///
		(both, keep(  postC19high_div_invent ) msymbol(D)  ) ///
		,yline(0) ytitle("Sales (log)") legend(order( 8 "low diversification & inventory" 2 "high diversification" 4 "high inventory" 6 "high inventory & high diversification")) nooffsets ///
		groups(preC19* = "{bf:Pre C-19 period}" C19* = "{bf:C-19 peak}" postC19* = "{bf:Recovery}", nogap ) ciopts(recast(rcap)) ///
		xline(3.5 7.5 11.5 15.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical xlabel(,nolabel) ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)
	
	
	graph export "$graphs/Network_heterogeneity/covid_dummies_high_div_inventory.png", replace


			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N df_a_nested r2  firm_fe  decfe sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. firms" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/covid_dummies_high_div_inventory.tex", $formatting $regshort $statslabelslr  

	


*********************************************************************************
*Eventstudy plots
*********************************************************************************

	grstyle set color default, order(2 1 2 1 2 1 2 1)
	foreach num of numlist 1/10{
	grstyle linewidth p`num' thin
}

		rename (jan_2020 $eventstudy2020 ) (m20_january m20_novem m20_decm  m20_february m20_march m20_april m20_may m20_june m20_july m20_august m20_septem m20_octob )
		global eventstudy2020 m20_novem m20_decm  m20_february m20_march m20_april m20_may m20_june m20_july m20_august m20_septem m20_octob 

		rename ($eventstudy2021 ) (m21_novem m21_decem m21_january m21_february m21_march)
		global eventstudy2021 m21_novem m21_decem m21_january m21_february m21_march

	******************
	*Sales levels
	
		cap drop pre
		cap drop pre_int
		
	gen pre=(date<718)
	gen pre_int=pre*div_ex_sales
	
	 
	
foreach var of varlist high_inventory div_ex_purch div_ex_sales high_complex_sales high_complex_purch Rhhi_indu_sales Rhhi_indu_purch  {
	
	cap drop ap1* ap2*
	
	
	gen ap1`var'=(`var'==0)
	gen ap2`var'=(`var'==1)

	foreach num of numlist 1{
				cap drop a`num'_*
	
	foreach month of varlist pre2020 $eventstudy2020 $eventstudy2021 m20_january {
			
			
			gen byte a`num'_`month'=`var'*`month'
					
		*Variable labels
			global a`num'
		label variable a`num'_`month' "`: var label `month''"
			global a`num' a`num'_*

		}
}

	  
	
	reghdfe ln_sales `var' pre2020 $eventstudy2020 $eventstudy2021 m20_january  $a1 Rfd_share ln_age importer exporter  if date>674 & sector_id!=10 , absorb(tax_payer_id   sector_id#month  ) vce(cluster tax_payer_id) pool(1) compact 
	estimates store a1
	estimates store a2
	
	coefplot ///
	(a1, keep( $eventstudy2020 $eventstudy2021 m20_january )  msymbol(D) mfcolor(*.7))  ///
	(a2, keep(  $a1   a1_m20_january) drop(a1_pre2020)  rename(a1_m20_* = m20_ a1_m21_* = m21_ ) msymbol(S) clpattern(longdash) mfcolor(*.7))  ///
	 , vertical yline(0) yscale(r(0)) ///
	text(-0.88 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.88 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l l l l l l l) ciopts(recast(rcap)) ///
	legend(order(2 "base group" 4 "interaction (time dummy * high diversification)" ) rows(1) ) ytitle("Sales (log)") order( m20_novem m20_decm m20_january m20_february) omitted
	

	graph export "$graphs/Network_heterogeneity/time_plot_jan_norm_`var'.png", replace

}

********************************************************************************
*Inventory (CIT firms only)
********************************************************************************

foreach var of varlist high_inventory   {
	
	cap drop ap1* ap2*
	
	
	gen ap1`var'=(`var'==0)
	gen ap2`var'=(`var'==1)

	foreach num of numlist 1{
				cap drop a`num'_*
	
	foreach month of varlist pre2020 $eventstudy2020 $eventstudy2021 m20_january {
			
			
			*gen byte a`num'_`month'=ap`num'`var'*`month'
			gen byte a`num'_`month'=`var'*`month'
					
		*Variable labels
			global a`num'
		label variable a`num'_`month' "`: var label `month''"
			global a`num' a`num'_*

		}
}

	  
	
	reghdfe ln_sales `var' pre2020 $eventstudy2020 $eventstudy2021 m20_january  $a1 Rfd_share ln_age importer exporter  if date>674 & sector_id!=10 & Lcit==1 , absorb(tax_payer_id   sector_id#month  ) vce(cluster tax_payer_id) pool(1) compact 
	estimates store a1
	estimates store a2
	
	coefplot ///
	(a1, keep( $eventstudy2020 $eventstudy2021 m20_january )  msymbol(D) mfcolor(*.7))  ///
	(a2, keep(  $a1   a1_m20_january) drop(a1_pre2020)  rename(a1_m20_* = m20_ a1_m21_* = m21_ ) msymbol(S) clpattern(longdash) mfcolor(*.7))  ///
	 , vertical yline(0) yscale(r(0)) ///
	text(-0.88 2.5 "2020", placem(r) size(small)) text(0.85 5 "<- first Covid case", placem(r) size(small)) text(-0.88 14.5 "2021", placem(r) size(small)) ///
	xline(5, lcolor(gs12) lpattern(longdash)) nooffsets connect(l l l l l l l l l l l) ciopts(recast(rcap)) ///
	legend(order(2 "base group" 4 "interaction (time dummy * high diversification)" ) rows(1) ) ytitle("Sales (log)") order( m20_novem m20_decm m20_january m20_february) omitted
	

	graph export "$graphs/Network_heterogeneity/time_plot_jan_norm_`var'.png", replace

}
