*******************************************************************************
*
*Firm level regression and international import and export shocks
*
********************************************************************************


********************************************************************************
*Add shock measures
********************************************************************************
	frame change firms_monthly
		 
	xtset tax_payer_id date
		cap drop _merge
		
	*Shock exposure
	merge 1:1 tax_payer_id date using "$data/Working_files/full_shock_exposure/Output/total_shocks_monthly_Rnetwork", keepusing(networkdate X* r_iX* sum_share*)
		rename _merge downnetwork

	merge 1:1 tax_payer_id date using "$data/Working_files/full_shock_exposure/Output/total_shocks_imports_monthly_Rnetwork", keepusing(networkdate M* r_iM*)
		rename _merge upnetwork

********************************************************************************
*Set shock measures to zero for firms that don't participate in network
********************************************************************************

		********************************
		*Sum of shares
		foreach var of varlist X* M* sum_share* {
			replace `var'=0 if `var'==.
			
		}
		
		foreach var of varlist r_i*{
			replace `var'=0 if `var'==.
			replace `var'=0 if `var'<0
			replace `var'=1 if `var'>1 & `var'!=.
			
		}

		cap drop _merge

		*Correct for outliers in import shocks
		foreach var of varlist M* X*{
			replace `var'=. if `var'<-15 | `var'>15
		}


********************************************************************************
*Change variables
********************************************************************************
	gen tag_liability=(total_liabilities>0 & total_liabilities!=.) if gross_profit!=0
	egen borrower=max(tag_liability), by(tax_payer_id)
		cap drop tag_liability
	cap gen ln_age=ln(firm_age)
	
	rename XexportUN_VAT12 Xexport_12
	rename MimportsUN_VAT12 Mimport_12
	rename XexportUN_customs12 Xcexport_12
	rename MimportUN_customs12 Mcimport_12
	rename Xd12log_total Xtotal_12
	cap rename Md12log_total Mtotal_12
	rename Xd12log_indirect Xd12log_ind
	cap rename Md12log_indirect Md12log_ind
	
	global demanddirect HsalesH_12 Xexport_12
	global importdirect Mimport_12
	global demandindirect Hd12log_ind Xd12log_ind
	global importindirect Md12log_ind
	global demandtotal Htotal_12 Xtotal_12
	global importtotal Mtotal_12
	

********************************************************************************
*Variable labels
********************************************************************************
	label variable Xtotal_12 "export total"
	label variable Xd12log_ind "export indirect"
	label variable Xexport_12 "export direct"

	label variable Mtotal_12 "import total"
	label variable Md12log_ind "import indirect"
	label variable Mimport_12 "import direct"

********************************************************************************
*Outcomes and controls
********************************************************************************
	
	*Outcome variables
	global outcomes ln_imports ln_exports ln_domestic_sales ln_domestic_purchases ln_supplier ln_buyer ln_employ

	
	*Sum of shares
	global sum_customs sum_share_imports_customs sum_share_exports_customs
	global sum_VAT r_iX_indirect sum_share_exports_VAT sum_share_imports_VAT r_iM_indirect

		global age
	foreach var of varlist $sum_VAT{
		gen age`var'=ln_age*`var'
		global age $age age`var'
	}

	foreach var of varlist ln_sales $outcomes{
			cap drop d12`var'
		gen d12`var'=`var'-L12.`var'
			label variable d12`var' "`:variable label `var''"
	}
	
********************************************************************************
*Shock pass through
********************************************************************************
				
	
	*Other outcomes
			estimates clear


	foreach outcome of varlist  $outcomes{
			reghdfe d12`outcome' Xexport_12 Xd12log_ind Mimport_12 Md12log_ind $sum_VAT $age  if date>698 & sector_id!=10 & d12ln_supplier!=. , absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	eststo `outcome'
						estadd local firm_fe \ding{51}
						estadd local sm_fe \ding{51}
						estadd local nofirms `e(N_clust)'

	}
	
			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N nofirms r2  firm_fe  sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. of firms" "R2"  "Firm FE" "Sector-date FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons $sum_VAT $age )	order(X* M*)

			esttab *  using "$tables/Network_heterogeneity/int_shocks_directindirect_primaryoutcomes.tex", $formatting $regshort $statslabelslr  
	
	
********************************************************************************
*Covid and substitution effects
********************************************************************************
			estimates clear

	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}

		grstyle set color rampshort, order(2 4 5)
		
	foreach outcome of varlist d12*{

	foreach var of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {
*
		

		cap drop C19`var'
		cap drop postC19`var'
		
		
			cap drop preC19`var'
			*gen preC19`var'=preC19*`var'
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' " "
			label variable postC19`var' " "
			*label variable preC19`var' " "
		label variable C19 "peak"
		label variable postC19 "recov"
		label variable preC19 " "
		label variable `var' " "
	}
	


	*Testing for pre-trends	
	reghdfe `outcome' C19 postC19 *Xexport_12 *Xd12log_ind *Mimport_12 *Md12log_ind  $sum_VAT $age   if date>698 & sector_id!=10 & d12ln_supplier!=., absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	estimates store `outcome'
	

						estadd local firm_fe \ding{51}
						estadd local sm_fe \ding{51}
						estadd local nofirms `e(N_clust)'

		coefplot (`outcome', keep(Xexport_12 Xd12log_ind Mimport_12 Md12log_ind) msymbol(S) mfcolor(*.3) ) ///
		(`outcome', keep(C19*)  msymbol(O)  mfcolor(*.5)  ) ///
		(`outcome', keep(postC19*)  msymbol(D) mfcolor(*.9)  ) ///
		,yline(0) ytitle("`:variable label `outcome''") legend(order( 2 "base (pre C-19)" 4 "* C-19 peak" 6 "* C-19 recovery") row(1)) nooffsets ///
		groups(C19 postC19 = "period dummies"  *Xexport_12 = "{bf:direct exports}" *Xd12log_ind = "{bf:indirect exports}" *Mimport_12 = "{bf:direct imports}" *Md12log_ind = "{bf:indirect imports}", nogap ) ciopts(recast(rcap)) ///
		xline(3.5 6.5 9.5, lcolor(gs12) lwidth(vthin) lpattern(longdash) ) vertical ///
		order(C19 postC19 *Xexport_12 *Xd12log_ind *Mimport_12 *Md12log_ind) ///
				mlabel format(%9.2g) mlabposition(3) mlabgap(*3)

	
	*****************
	*Graphs
	graph export "$graphs/Network_heterogeneity/int_shocks_C19_`outcome'.png", replace

	}	
			*******************
			*Tables
			label variable C19 "C-19 peak"
			label variable postC19 "C-19 recovery"
			label variable preC19 "Pre C-19 period"
				label variable Xtotal_12 "export total"
				label variable Xd12log_ind "export indirect"
				label variable Xexport_12 "export direct"

				label variable Mtotal_12 "import total"
				label variable Md12log_ind "import indirect"
				label variable Mimport_12 "import direct"

			foreach var of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind{
			label variable C19`var' "`: variable label C19'*`:variable label `var''"
			label variable postC19`var' "`: variable label postC19'*`:variable label `var''"
}

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N nofirms r2  firm_fe  sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. of firms" "R2"  "Firm FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons $sum_VAT $age )	order(C19 postC19 *X* *M*)

			esttab *  using "$tables/Network_heterogeneity/int_shocks_C19.tex", $formatting $regshort $statslabelslr  
	
********************************************************************************
*Robustness checks
********************************************************************************

	*****************************
	*Excluding firms with either total exports or imports =1 - which are often the highly connected firms
			estimates clear
			
	foreach outcome of varlist  $outcomes{
			reghdfe d12`outcome' Xexport_12 Xd12log_ind Mimport_12 Md12log_ind $sum_VAT $age  if date>698 & sector_id!=10 & d12ln_supplier!=. & r_iM_total<1 & r_iX_total<1 , absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	eststo `outcome'
						estadd local firm_fe \ding{51}
						estadd local sm_fe \ding{51}
						estadd local nofirms `e(N_clust)'

	}
	
			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N nofirms r2  firm_fe  sm_fe, fmt(%12.0gc %12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "No. of firms" "R2"  "Firm FE" "Sector-date FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons $sum_VAT $age )	order(X* M*)

			esttab *  using "$tables/Network_heterogeneity/int_shocks_directindirect_primaryoutcomes_excl_total1.tex", $formatting $regshort $statslabelslr  
	
	

			estimates clear

	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}

		grstyle set color rampshort, order(2 4 5)
		
********************************************************************************
*Network position and pass-through of shocks (not interacted with Covid period dummies due to lack of power)
********************************************************************************

	grstyle set color default, order(1 2 1 2 1 2 1 2 1)
		
	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}
	
foreach outcome of varlist ln_imports ln_exports ln_domestic_sales ln_domestic_purchases ln_sales{
foreach x in  "purch" "sales" {
	foreach var of varlist  div_ex_`x' high_complex_`x' Rhhi_indu_`x' {

		if "`x'"=="purch"{
			local flow = "up"
		}
		else{
			local flow = "down"
		}
		

	foreach x of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {
*
		

		cap drop `x'`var'
	
		gen `x'`var'=`var'*`x'
			label variable `x'`var' "inter"
		label variable `x' "base"
	}
		estimates clear


	*Testing for pre-trends	
	reghdfe d12`outcome' `var' Xexport_12 Xexport_12`var' Xd12log_ind Xd12log_ind`var' Mimport_12 Mimport_12`var' Md12log_ind Md12log_ind`var'  $sum_VAT $age   if date>698 & sector_id!=10 & d12ln_supplier!=., absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(Xexport_12) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(Xexport_12`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(Xd12log_ind) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(Xd12log_ind`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(Mimport_12) msymbol(O)  ) ///
		(`var', keep(Mimport_12`var' ) msymbol(S)  ) ///
		(`var', keep(Md12log_ind) msymbol(O)  ) ///
		(`var', keep(Md12log_ind`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("`: variable label `outcome'' (log)") legend(order( 4 "no/low `flow'stream diversification" 2 "high `flow'stream diversification")) nooffsets ///
		groups(Xexport_12* = "{bf:direct exports}" Xd12log_ind* = "{bf:indirect exports}" Mimport_12* = "{bf:direct imports}" Md12log_ind* = "{bf:indirect imports}", nogap) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5 7.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)

	
	*****************
	*Graphs
	graph export "$graphs/Network_heterogeneity/int_shock_`outcome'_`var'.png", replace

	
			*******************
			*Tables
			label variable Xtotal_12 "export total"
			label variable Xd12log_ind "export indirect"
			label variable Xexport_12 "export direct"

			label variable Mtotal_12 "import total"
			label variable Md12log_ind "import indirect"
			label variable Mimport_12 "import direct"
		foreach x of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {

			label variable `x'`var' "`: variable label `x''*`:variable label `var''"
		}	
			

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N r2  firm_fe  decfe sm_fe, fmt(%12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/int_shock_`outcome'_`var'.tex", $formatting $regshort $statslabelslr  
			
	drop `x'`var'
	
	}
	
}
	

	}
	
********************************************************************************
*Inventory
********************************************************************************

	grstyle set color default, order(1 2 1 2 1 2 1 2 1)
		
	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}
	foreach var of varlist  high_inventory  {
	foreach x of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {
*
		

		*cap drop `x'`var'
	
		gen `x'`var'=`var'*`x'
			label variable `x'`var' "inter"
		label variable `x' "base"
	}
	
foreach outcome of varlist  ln_exports ln_imports ln_domestic_sales ln_domestic_purchases ln_sales{

		estimates clear


	*Testing for pre-trends	
	reghdfe d12`outcome' `var' Xexport_12 Xexport_12`var' Xd12log_ind Xd12log_ind`var' Mimport_12 Mimport_12`var' Md12log_ind Md12log_ind`var'  $sum_VAT $age   if date>698 & sector_id!=10 & d12ln_supplier!=., absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	estimates store `var'
	
		cap drop group`var'
		gen group`var'=(e(sample)==1)

						estadd local firm_fe \ding{51}
						estadd local decfe \ding{51}
						estadd local sm_fe \ding{51}

		coefplot (`var', keep(`var' ) msymbol(S) mfcolor(*.5) ) ///
		(`var', keep(Xexport_12) msymbol(O)  mfcolor(*.3)  ) ///
		(`var', keep(Xexport_12`var') msymbol(S) mfcolor(*.3)  ) ///
		(`var', keep(Xd12log_ind) msymbol(O)  mfcolor(*.7)  ) ///
		(`var', keep(Xd12log_ind`var') msymbol(S) mfcolor(*.7)  ) ///
		(`var', keep(Mimport_12) msymbol(O)  ) ///
		(`var', keep(Mimport_12`var' ) msymbol(S)  ) ///
		(`var', keep(Md12log_ind) msymbol(O)  ) ///
		(`var', keep(Md12log_ind`var' ) msymbol(S)  ) ///
		,yline(0) ytitle("`: variable label `outcome'' (log)") legend(order( 4 "no/low inventory" 2 "high inventory")) nooffsets ///
		groups(Xexport_12* = "{bf:direct exports}" Xd12log_ind* = "{bf:indirect exports}" Mimport_12* = "{bf:direct imports}" Md12log_ind* = "{bf:indirect imports}", nogap) ciopts(recast(rcap)) ///
		xline(1.5 3.5 5.5 7.5, lcolor(gs14) lwidth(vthin) lpattern(longdash) ) vertical ///
		mlabel format(%9.2g) mlabposition(3) mlabgap(*3)

	
	*****************
	*Graphs
	graph export "$graphs/Network_heterogeneity/int_shock_`outcome'_`var'.png", replace

	
			*******************
			*Tables
			label variable Xtotal_12 "export total"
			label variable Xd12log_ind "export indirect"
			label variable Xexport_12 "export direct"

			label variable Mtotal_12 "import total"
			label variable Md12log_ind "import indirect"
			label variable Mimport_12 "import direct"
		foreach x of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {

			label variable `x'`var' "`: variable label `x''*`:variable label `var''"
		}	
			

			local footnote "*; **; and *** denote significance at the 10; 5; and 1 percent levels respectively."
			global regshort 		"stats(N r2  firm_fe  decfe sm_fe, fmt(%12.0gc 3)" // Added Statistics
			global statslabelslr 	l("No. observations" "R2"  "Firm FE" "Sales decile FE" "Sector-month FE" )) // Labels
			global formatting 	replace se    booktabs l  nogaps starlevels(* 0.10 ** 0.05 *** 0.01) noomitted nobaselevels  compress c(b(s fmt(3)) se(par(( )) fmt(3)))    nonumber   collabels(, none) drop(_cons)	

			esttab *  using "$tables/Network_heterogeneity/int_shock_`outcome'_`var'.tex", $formatting $regshort $statslabelslr  
			
	foreach x of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {
			label variable `x'`var' "inter"
		label variable `x' "base"
	}
	
	}
	
}
	

********************************************************************************
*Covid robustness checks
********************************************************************************
			

			estimates clear

	foreach num of numlist 1/10{
	grstyle linewidth p`num' medium
}

		grstyle set color rampshort, order(2 4 5)
			gen negative=(Xexport_12<=0 & Xd12log_ind<=0 & Mimport_12<=0 & Md12log_ind<=0 ) & C19==1
		egen max_negative=max(negative), by(tax_payer_id)

		gen positive=(Xexport_12>=0 & Xd12log_ind>=0 & Mimport_12>=0 & Md12log_ind>=0 ) & C19==1
		egen max_positive=max(positive), by(tax_payer_id)
	
	foreach outcome of varlist $outcomes{

	foreach var of varlist Xexport_12 Xd12log_ind Mimport_12 Md12log_ind {
*

		cap drop C19`var'
		cap drop postC19`var'
		
		
			cap drop preC19`var'
		gen C19`var'=C19*`var'
		gen postC19`var'=postC19*`var'
			label variable C19`var' " "
			label variable postC19`var' " "
		label variable C19 "peak"
		label variable postC19 "recov"
		label variable preC19 " "
		label variable `var' " "
	}
	
foreach direction in negative positive{

	*Testing for pre-trends	
	reghdfe `outcome' C19 postC19 *Xexport_12 *Xd12log_ind *Mimport_12 *Md12log_ind  $sum_VAT $age   if date>698 & sector_id!=10 & d12ln_supplier!=. & max_`direction'==1, absorb(tax_payer_id sector_id#date) vce(cluster tax_payer_id)
	estimates store `outcome'
	

						estadd local firm_fe \ding{51}
						estadd local sm_fe \ding{51}
						estadd local nofirms `e(N_clust)'

		coefplot (`outcome', keep(Xexport_12 Xd12log_ind Mimport_12 Md12log_ind) msymbol(S) mfcolor(*.3) ) ///
		(`outcome', keep(C19*)  msymbol(O)  mfcolor(*.5)  ) ///
		(`outcome', keep(postC19*)  msymbol(D) mfcolor(*.9)  ) ///
		,yline(0) ytitle("`:variable label `outcome''") legend(order( 2 "base (pre C-19)" 4 "* C-19 peak" 6 "* C-19 recovery") row(1)) nooffsets ///
		groups(C19 postC19 = "period dummies"  *Xexport_12 = "{bf:direct exports}" *Xd12log_ind = "{bf:indirect exports}" *Mimport_12 = "{bf:direct imports}" *Md12log_ind = "{bf:indirect imports}", nogap ) ciopts(recast(rcap)) ///
		xline(3.5 6.5 9.5, lcolor(gs12) lwidth(vthin) lpattern(longdash) ) vertical ///
		order(C19 postC19 *Xexport_12 *Xd12log_ind *Mimport_12 *Md12log_ind) ///
				mlabel format(%9.2g) mlabposition(3) mlabgap(*3)
	
		graph export "$graphs/Network_heterogeneity/int_shocks_C19_`outcome'_`direction'.png", replace

}

	}	

	
		